@@ -1,10 +1,10 @@
 /**
  * @file    editor.c
- * @brief   
+ * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
- * 
+ *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
  * files (the "Software"), to deal in the Software without
@@ -32,12 +32,9 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <sys/stat.h>
 
-#include <gtksourceview/gtksourcebuffer.h>
-#include <gtksourceview/gtksourceiter.h>
-#include <gtksourceview/gtksourcelanguagemanager.h>
-#include <gtksourceview/gtksourcestyleschememanager.h>
-#include <gtksourceview/gtksourceview.h>
+#include <gtksourceview/gtksource.h>
 #ifdef USE_GTKSPELL
 #   include <gtkspell/gtkspell.h>
 #endif
@@ -54,7 +51,7 @@ static void on_inserted_text(GtkTextBuffer *textbuffer,GtkTextIter *location,
                              gchar *text,gint len, gpointer user_data);
 static void on_delete_range(GtkTextBuffer *textbuffer,GtkTextIter *start,
                              GtkTextIter *end, gpointer user_data);
-                             
+
 const gchar style[][3][20] = {
     { "tool_bold", "\\textbf{", "}" },
     { "tool_italic", "\\emph{", "}" },
@@ -76,7 +73,7 @@ GuEditor* editor_new (GuMotion* mc) {
     ec->workfile = NULL;
     ec->bibfile = NULL;
     ec->projfile = NULL;
-    
+
     GtkSourceLanguageManager* manager = gtk_source_language_manager_new ();
     GtkSourceLanguage* lang = gtk_source_language_manager_get_language (manager,
             "latex");
@@ -88,16 +85,24 @@ GuEditor* editor_new (GuMotion* mc) {
     ec->editortags = gtk_text_buffer_get_tag_table (ec_buffer);
     ec->replace_activated = FALSE;
     ec->term = NULL;
-    
-    gtk_source_view_set_tab_width (ec->view,
-            atoi (config_get_value ("tabwidth")));
-    gtk_source_view_set_insert_spaces_instead_of_tabs (ec->view,
-            TO_BOOL (config_get_value ("spaces_instof_tabs")));
-    gtk_source_view_set_auto_indent (ec->view,
-            TO_BOOL (config_get_value ("autoindentation")));
+
+    ec->css = gtk_css_provider_new();
+
+    /* Set source view style provider so we can use ec->css to set font later */
+    GtkStyleContext* context = gtk_widget_get_style_context (GTK_WIDGET(ec->view));
+    gtk_style_context_add_provider(context,
+                                   GTK_STYLE_PROVIDER(ec->css),
+                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
+    gtk_source_view_set_tab_width
+        (ec->view, config_get_integer ("Editor", "tabwidth"));
+    gtk_source_view_set_insert_spaces_instead_of_tabs
+        (ec->view, config_get_boolean ("Editor", "spaces_instof_tabs"));
+    gtk_source_view_set_auto_indent
+        (ec->view, config_get_boolean ("Editor", "autoindentation"));
 
 #ifdef USE_GTKSPELL
-    if (config_get_value ("spelling"))
+    if (config_get_boolean ("Editor", "spelling"))
         editor_activate_spellchecking (ec, TRUE);
 #endif
 
@@ -112,9 +117,9 @@ GuEditor* editor_new (GuMotion* mc) {
     ec->sigid[2] = g_signal_connect (ec->buffer, "changed",
                 G_CALLBACK (check_preview_timer), NULL);
 
-    ec->sigid[3] = g_signal_connect_after(ec->buffer, "insert-text", 
+    ec->sigid[3] = g_signal_connect_after(ec->buffer, "insert-text",
                 G_CALLBACK(on_inserted_text), ec);
-    ec->sigid[4] = g_signal_connect_after(ec->buffer, "delete-range", 
+    ec->sigid[4] = g_signal_connect_after(ec->buffer, "delete-range",
                 G_CALLBACK(on_delete_range), ec);
 
     return ec;
@@ -122,7 +127,7 @@ GuEditor* editor_new (GuMotion* mc) {
 
 void editor_destroy (GuEditor* ec) {
     gint i = 0;
-    
+
     for (i = 0; i < 2; ++i) {
         if (g_signal_handler_is_connected (ec->view, ec->sigid[i])) {
             g_signal_handler_disconnect (ec->view, ec->sigid[i]);
@@ -145,7 +150,7 @@ static void on_inserted_text(GtkTextBuffer *textbuffer,GtkTextIter *location,
         return;
     }
     GuEditor* e = GU_EDITOR(user_data);
-    
+
     e->last_edit = *location;
     e->sync_to_last_edit = TRUE;
 }
@@ -157,7 +162,7 @@ static void on_delete_range(GtkTextBuffer *textbuffer,GtkTextIter *start,
         return;
     }
     GuEditor* e = GU_EDITOR(user_data);
-    
+
     e->last_edit = *start;
     e->sync_to_last_edit = TRUE;
 }
@@ -173,26 +178,32 @@ static void on_delete_range(GtkTextBuffer *textbuffer,GtkTextIter *start,
  * Since pdflatex refuses to compile TeX files with '.' prefixed, we have to
  * set the environment variable 'openout_any=a'.
  *
- * For a newly created document, all files including the TeX file is stored
- * under the temp directory. For files that are already saved, only the
- * workfile is saved under DIRNAME (FILENAME). Other compilation-related files
- * are located in the temp directory.
+ * For a newly created document, all files including the TeX file are stored
+ * under the ~/.cache folder (freedesktop XDG standard). For files that are 
+ * already saved, only the workfile is saved under DIRNAME (FILENAME). 
+ * Other compilation-related files are located in the temp directory.
  *
  * P.S. pdflatex will automatically strip the suffix, so for a file named
  * FILE.tex under /absolute/path/:
  *
  * filename = /absolute/path/FILE.tex
  * workfile = /absolute/path/.FILE.tex.swp
- * pdffile = /tmp/.FILE.tex.pdf
+ * pdffile = ~/cache/gummi/.FILE.tex.pdf
  */
 void editor_fileinfo_update (GuEditor* ec, const gchar* filename) {
 
+    // directory should exist, but if not create ~/.cache/gummi:
+    if (!g_file_test (C_TMPDIR, G_FILE_TEST_IS_DIR)) {
+            slog (L_WARNING, ".cache directory does not exist, creating..\n");
+            g_mkdir_with_parents (C_TMPDIR, DIR_PERMS);
+    }
+
     if (ec->workfd != -1)
         editor_fileinfo_cleanup (ec);
 
     ec->fdname = g_build_filename (C_TMPDIR, "gummi_XXXXXX", NULL);
     ec->workfd = g_mkstemp (ec->fdname);
-    
+
     // This is required for Windows 7, but not for Linux. It may also
     // be the proper way for *nix, but I don't want to change this
     // crucial piece of code at this stage of development -alexander
@@ -201,13 +212,27 @@ void editor_fileinfo_update (GuEditor* ec, const gchar* filename) {
 	#endif
 
     if (filename) {
-        gchar* base = g_path_get_basename (filename);
-        gchar* dir = g_path_get_dirname (filename);
-        ec->filename = g_strdup (filename);
+        gchar* fname = NULL;
+        if (!g_path_is_absolute (filename)) {
+            fname = g_strdup_printf ("%s%c%s", g_get_current_dir(),
+                                     G_DIR_SEPARATOR, filename);
+        } else {
+            fname = g_strdup (filename);
+        }
+
+        gchar* base = g_path_get_basename (fname);
+        gchar* dir = g_path_get_dirname (fname);
+        ec->filename = g_strdup (fname);
         ec->basename = g_strdup_printf ("%s%c.%s", dir, G_DIR_SEPARATOR, base);
         ec->workfile = g_strdup_printf ("%s.swp", ec->basename);
         ec->pdffile =  g_strdup_printf ("%s%c.%s.pdf", C_TMPDIR,
                                        G_DIR_SEPARATOR, base);
+        // Get last modified time
+        struct stat attr;
+        stat(fname, &attr);
+        ec->last_modtime = attr.st_mtime;
+
+        g_free (fname);
         g_free (base);
         g_free (dir);
     } else {
@@ -233,7 +258,7 @@ void editor_fileinfo_cleanup (GuEditor* ec) {
     gchar* auxfile = NULL;
     gchar* logfile = NULL;
     gchar* syncfile = NULL;
-    
+
     if (ec->filename) {
         gchar* dirname = g_path_get_dirname (ec->filename);
         gchar* basename = g_path_get_basename (ec->filename);
@@ -255,7 +280,7 @@ void editor_fileinfo_cleanup (GuEditor* ec) {
         g_free (dirname);
     }
 
-    // TODO: make a loop or maybe make register of created files? proc? 
+    // TODO: make a loop or maybe make register of created files? proc?
 
     close (ec->workfd);
     ec->workfd = -1;
@@ -289,24 +314,22 @@ void editor_sourceview_config (GuEditor* ec) {
 
     gtk_source_buffer_set_highlight_matching_brackets (ec->buffer, TRUE);
 
-    const gchar* style_scheme = config_get_value ("style_scheme");
+    const gchar* style_scheme = config_get_string ("Editor", "style_scheme");
     editor_set_style_scheme_by_id (ec, style_scheme);
 
-    const gchar* font = config_get_value ("font");
-    slog (L_INFO, "setting font to %s\n", font);
-    PangoFontDescription* font_desc = pango_font_description_from_string (font);
-    gtk_widget_modify_font (GTK_WIDGET (ec->view), font_desc);
-    pango_font_description_free (font_desc);
+    editor_set_font (ec, config_get_string ("Editor", "font"));
 
-    gtk_source_view_set_show_line_numbers (GTK_SOURCE_VIEW (ec->view),
-            TO_BOOL (config_get_value ("line_numbers")));
-    gtk_source_view_set_highlight_current_line (GTK_SOURCE_VIEW (ec->view),
-        TO_BOOL (config_get_value ("highlighting")));
+    gtk_source_view_set_show_line_numbers (
+                            GTK_SOURCE_VIEW (ec->view),
+                            config_get_boolean ("Editor", "line_numbers"));
+    gtk_source_view_set_highlight_current_line (
+                            GTK_SOURCE_VIEW (ec->view),
+                            config_get_boolean ("Editor", "highlighting"));
 
-    /* The condition 'textwrapping=False && wordwrapping=True' can't happen */
-    if (config_get_value ("textwrapping"))
+    // The condition 'textwrapping=False && wordwrapping=True' can't happen
+    if (config_get_boolean ("Editor", "textwrapping"))
         wrapmode += 1;
-    if (config_get_value ("wordwrapping"))
+    if (config_get_boolean ("Editor", "wordwrapping"))
         wrapmode += 1;
 
     gtk_text_view_set_wrap_mode (ec_view, wrapmode);
@@ -315,24 +338,25 @@ void editor_sourceview_config (GuEditor* ec) {
 
 #ifdef USE_GTKSPELL
 void editor_activate_spellchecking (GuEditor* ec, gboolean status) {
-    const gchar* lang = config_get_value ("spell_language");
+    const gchar* lang = config_get_string ("Editor", "spelling_lang");
     GError* err = NULL;
-    GError* err2 = NULL;
-    GtkSpell* spell = 0;
+    GtkSpellChecker* spell = 0;
     if (status) {
-        if (! (spell = gtkspell_new_attach (ec_view, "en", &err))) {
-            slog (L_ERROR, "gtkspell_new_attach (): %s\n", err->message);
+        spell = gtk_spell_checker_new();
+
+        if (! (gtk_spell_checker_set_language (spell, lang, &err))) {
+            slog (L_ERROR, "gtk_spell_checker_set_language (): %s\n", err->message);
             g_error_free (err);
         }
-        if (!gtkspell_set_language (spell, lang, &err2)) {
-            slog (L_ERROR, "gtkspell_set_language (): %s\n", err2->message);
-            g_error_free (err2);
+        if (! (gtk_spell_checker_attach (spell, ec_view))) {
+            slog (L_ERROR, "gtk_spell_checker_attach failed\n");
         }
     } else {
-        GtkSpell* spell = gtkspell_get_from_text_view (ec_view);
+        GtkSpellChecker* spell = gtk_spell_checker_get_from_text_view (ec_view);
         if (spell)
-            gtkspell_detach (spell);
+            gtk_spell_checker_detach (spell);
     }
+    // TODO g_object_unref (spell); ?
 }
 #endif
 
@@ -367,9 +391,17 @@ gboolean editor_buffer_changed (GuEditor* ec) {
     return FALSE;
 }
 
-void editor_insert_package (GuEditor* ec, const gchar* package) {
+void editor_insert_package (GuEditor* ec, const gchar* package, const gchar* options) {
     GtkTextIter start, mstart, mend, sstart, send;
-    gchar* pkgstr = g_strdup_printf ("\\usepackage{%s}\n", package);
+
+    gchar* pkgstr = NULL;
+    if (options == NULL) {
+        pkgstr = g_strdup_printf ("\\usepackage{%s}\n", package);
+    }
+    else {
+        pkgstr = g_strdup_printf ("\\usepackage[%s]{%s}\n", options, package);
+    }
+
     gtk_text_buffer_get_start_iter (ec_buffer, &start);
     gtk_text_iter_forward_search (&start, (gchar*)"\\begin{document}", 0,
             &mstart, &mend, NULL);
@@ -526,16 +558,18 @@ void editor_apply_searchtag (GuEditor* ec) {
     gtk_text_tag_table_add (ec->editortags, ec->searchtag);
 
     while (TRUE) {
-        ret = gtk_source_iter_forward_search (&start, ec->term,
-                (ec->matchcase? 0: GTK_SOURCE_SEARCH_CASE_INSENSITIVE),
-                &mstart, &mend, NULL);
+		do {
+			ret = gtk_text_iter_forward_search (&start, ec->term,
+	                (ec->matchcase? 0: GTK_TEXT_SEARCH_CASE_INSENSITIVE),
+	                &mstart, &mend, NULL);
+			start = mend;
+		} while (ec->wholeword && ret && (!gtk_text_iter_starts_word(&mstart) ||
+				!gtk_text_iter_ends_word(&mend)));
 
-        if (ret && (!ec->wholeword || (ec->wholeword
-                        && gtk_text_iter_starts_word (&mstart)
-                        && gtk_text_iter_ends_word (&mend)))) {
+        if (ret) {
             gtk_text_buffer_apply_tag (ec_buffer, ec->searchtag,
                     &mstart, &mend);
-            start =  mend;
+//            start =  mend;
         } else break;
     }
 }
@@ -545,21 +579,23 @@ void editor_search_next (GuEditor* ec, gboolean inverse) {
     gboolean ret = FALSE, response = FALSE;
 
     editor_get_current_iter (ec, &current);
+	
+	do {
+	    if (ec->backwards ^ inverse) {
+	        ret = gtk_text_iter_backward_search (&current, ec->term,
+	                (ec->matchcase? 0: GTK_TEXT_SEARCH_CASE_INSENSITIVE),
+	                &mstart, &mend, NULL);
+	    } else {
+	        gtk_text_iter_forward_chars (&current, strlen (ec->term));
+	        ret = gtk_text_iter_forward_search (&current, ec->term,
+	                (ec->matchcase? 0: GTK_TEXT_SEARCH_CASE_INSENSITIVE),
+	                &mstart, &mend, NULL);
+		}
+		current = mend;
+	} while (ec->wholeword && ret && (!gtk_text_iter_starts_word(&mstart) ||
+			!gtk_text_iter_ends_word(&mend)));
 
-    if (ec->backwards ^ inverse) {
-        ret = gtk_source_iter_backward_search (&current, ec->term,
-                (ec->matchcase? 0: GTK_SOURCE_SEARCH_CASE_INSENSITIVE),
-                &mstart, &mend, NULL);
-    } else {
-        gtk_text_iter_forward_chars (&current, strlen (ec->term));
-        ret = gtk_source_iter_forward_search (&current, ec->term,
-                (ec->matchcase? 0: GTK_SOURCE_SEARCH_CASE_INSENSITIVE),
-                &mstart, &mend, NULL);
-    }
-
-    if (ret && (!ec->wholeword || (ec->wholeword
-            && gtk_text_iter_starts_word (&mstart)
-            && gtk_text_iter_ends_word (&mend)))) {
+    if (ret) {
         gtk_text_buffer_select_range (ec_buffer, &mstart, &mend);
         editor_scroll_to_cursor (ec);
     }
@@ -602,12 +638,12 @@ void editor_start_replace_next (GuEditor* ec, const gchar* term,
     editor_get_current_iter (ec, &current);
 
     if (backwards)
-       ret = gtk_source_iter_backward_search (&current, term,
-                (matchcase? 0: GTK_SOURCE_SEARCH_CASE_INSENSITIVE),
+       ret = gtk_text_iter_backward_search (&current, term,
+                (matchcase? 0: GTK_TEXT_SEARCH_CASE_INSENSITIVE),
                 &mstart, &mend, NULL);
     else
-       ret = gtk_source_iter_forward_search (&current, term,
-                (matchcase? 0: GTK_SOURCE_SEARCH_CASE_INSENSITIVE),
+       ret = gtk_text_iter_forward_search (&current, term,
+                (matchcase? 0: GTK_TEXT_SEARCH_CASE_INSENSITIVE),
                 &mstart, &mend, NULL);
 
     if (ret && (!wholeword || (wholeword
@@ -627,24 +663,30 @@ void editor_start_replace_all (GuEditor* ec, const gchar* term,
         gboolean matchcase) {
     GtkTextIter start, mstart, mend;
     gboolean ret = FALSE;
+    gboolean action_started = FALSE;
 
     gtk_text_buffer_get_start_iter (ec_buffer, &start);
 
     while (TRUE) {
-        ret = gtk_source_iter_forward_search (&start, term,
-                (matchcase? 0: GTK_SOURCE_SEARCH_CASE_INSENSITIVE),
+        ret = gtk_text_iter_forward_search (&start, term,
+                (matchcase? 0: GTK_TEXT_SEARCH_CASE_INSENSITIVE),
                 &mstart, &mend, NULL);
 
         if (ret && (!wholeword || (wholeword
                 && gtk_text_iter_starts_word (&mstart)
                 && gtk_text_iter_ends_word (&mend)))) {
-            gtk_text_buffer_begin_user_action (ec_buffer);
+            if (!action_started) {
+                gtk_text_buffer_begin_user_action (ec_buffer);
+                action_started = TRUE;
+            }
             gtk_text_buffer_delete (ec_buffer, &mstart, &mend);
             gtk_text_buffer_insert (ec_buffer, &mstart, rterm, -1);
-            gtk_text_buffer_end_user_action (ec_buffer);
             start =  mstart;
         } else break;
     }
+    if (action_started) {
+        gtk_text_buffer_end_user_action (ec_buffer);
+    }
 }
 
 void editor_get_current_iter (GuEditor* ec, GtkTextIter* current) {
@@ -689,128 +731,142 @@ void editor_redo_change (GuEditor* ec) {
     }
 }
 
+void editor_set_font (GuEditor* ec, const gchar* font) {
+    // surely there has to be a better solution to transform
+    // a string like 'Monospace 12' into css syntax right..?
+    gchar** font_elems = g_strsplit (font, " ", BUFSIZ);
+    gchar* style = g_strdup_printf ("* { font: %spx '%s'; }",
+                                    font_elems[1], font_elems[0]);
+
+    gtk_css_provider_load_from_data (ec->css, style, -1, NULL);
+    g_free (style);
+}
+
+
 void editor_set_style_scheme_by_id (GuEditor* ec, const gchar* id) {
-    
+
     GtkSourceStyleScheme* scheme =
         gtk_source_style_scheme_manager_get_scheme (ec->stylemanager, id);
-    slog (L_INFO, "setting styles scheme to %s\n", id);
+    slog (L_INFO, "Setting styles scheme to %s\n", id);
 
     if (!scheme) {
-        slog (L_ERROR, "no style scheme %s found, setting to classic\n", id);
+        slog (L_ERROR, "No style scheme %s found, setting to classic\n", id);
         scheme = gtk_source_style_scheme_manager_get_scheme (ec->stylemanager,
                 "classic");
     }
     gtk_source_buffer_set_style_scheme (ec->buffer, scheme);
-    
+
     set_style_fg_bg(G_OBJECT (ec->searchtag), scheme, "search-match", "yellow");
     set_style_fg_bg(G_OBJECT (ec->errortag), scheme,"def:error",  "red");
 }
 
-
-static inline gdouble gdkcolor_luminance(GdkColor c) {
-    return (0.2126 * c.red + 0.7152 * c.green + 0.0722 * c.blue) / G_MAXUINT16;
+static inline gdouble gdk_rgba_luminance (GdkRGBA c) {
+    return 0.2126 * c.red + 0.7152 * c.green + 0.0722 * c.blue;
 }
 
-
 /**
- *  Sets a object's fore- and background color to that of scheme's style 
- *  "styleName". If no background color is defined in the style, defaultBG is 
- *  used. defaultBG can be any valid parameter to gdk_color_parse().
+ *  Sets a object's fore- and background color to that of scheme's style
+ *  "styleName". If no background color is defined in the style, defaultBG is
+ *  used. defaultBG can be any valid parameter to gdk_rgba_parse().
  *  If only a foreground color was defined and it has not enough contrast to the
  *  default background, it will be overwritten. The foreground color will either
  *  be white or black, which has more contrast.
  */
-void set_style_fg_bg (GObject* obj, GtkSourceStyleScheme* scheme, 
+void set_style_fg_bg (GObject* obj, GtkSourceStyleScheme* scheme,
                       gchar* styleName, gchar* defaultBG) {
     GtkSourceStyle *style = NULL;
-    
+
     gchar *bg = NULL;
     gchar *fg = NULL;
     gboolean foreground_set;
     gboolean background_set;
-    GdkColor foreground;
-    GdkColor background;
+    GdkRGBA foreground;
+    GdkRGBA background;
 
 
     if (scheme == NULL) {
         goto set_style_fg_bg_return_defaults;
     }
-    
+
     style = gtk_source_style_scheme_get_style (scheme, styleName);
-    
+
     if (style == NULL) {
         goto set_style_fg_bg_return_defaults;
     }
-    
+
     // Get properties of style
-    g_object_get (style, 
-                  "foreground-set", &foreground_set, 
+    g_object_get (style,
+                  "foreground-set", &foreground_set,
                   "foreground", &fg,
-                  "background-set", &background_set, 
+                  "background-set", &background_set,
                   "background", &bg,
                   NULL);
 
     if (foreground_set) {
-        if (fg == NULL || !gdk_color_parse (fg, &foreground))
+        if (fg == NULL || !gdk_rgba_parse(&foreground, fg))
             foreground_set = FALSE;
     }
 
     if (background_set) {
-        if (bg == NULL || !gdk_color_parse (bg, &background))
+        if (bg == NULL || !gdk_rgba_parse(&background, bg))
             background_set = FALSE;
-    }    
+    }
 
     g_free(fg);
     g_free(bg);
-    
+
     if (background_set && foreground_set) {
         // We trust the style to set both to good values
         // Do nothing
     } else if (!background_set && foreground_set) {
         // Set bg to default and check if fg has enough contrast
-        gdk_color_parse(defaultBG, &background);
-        gdouble diff = ABS(gdkcolor_luminance(foreground) -
-                gdkcolor_luminance(background));
+        gdk_rgba_parse(&background, defaultBG);
+
+        gdouble diff = ABS(gdk_rgba_luminance(foreground) -
+                           gdk_rgba_luminance(background));
+
         if (diff < 0.5) {
             slog(L_INFO, "Style \"%s\" defines a foreground, but no background "
                          "color. As the fourground color has not enough "
                          "contrast to Gummis default background color, the "
                          "foreground color has been adjusted.\n", styleName);
-            if (gdkcolor_luminance(background) > 0.5) {
-                gdk_color_parse("black", &foreground);
+            if (gdk_rgba_luminance(background) > 0.5) {
+                gdk_rgba_parse(&foreground, "black");
             } else {
-                gdk_color_parse("white", &foreground);
+                gdk_rgba_parse(&foreground, "white");
             }
         }
     } else if (background_set && !foreground_set) {
-        // Choose a fg = white or black, which has more contrast   
-        if (gdkcolor_luminance(background) > 0.5) {
-            gdk_color_parse("black", &foreground);
+        // Choose a fg = white or black, which has more contrast
+        if (gdk_rgba_luminance(background) > 0.5) {
+            gdk_rgba_parse(&foreground, "black");
         } else {
-            gdk_color_parse("white", &foreground);
+            gdk_rgba_parse(&foreground, "white");
         }
     } else {
         // none set, set defaults
         goto set_style_fg_bg_return_defaults;
     }
-    
-    g_object_set (obj, "foreground-gdk", &foreground, 
-                        "background-gdk", &background, NULL);
+
+    g_object_set(obj, "foreground", gdk_rgba_to_string(&foreground),
+                      "background", gdk_rgba_to_string(&background), 
+                       NULL);
     return;
-                        
+
 set_style_fg_bg_return_defaults:
 
     // No valid style, set defaults
-    gdk_color_parse(defaultBG, &background);
-    if (gdkcolor_luminance(background) > 0.5) {
-        gdk_color_parse("black", &foreground);
+    gdk_rgba_parse(&background, defaultBG);
+
+    if (gdk_rgba_luminance(background) > 0.5) {
+        gdk_rgba_parse(&foreground, "black");
     } else {
-        gdk_color_parse("white", &foreground);
+        gdk_rgba_parse(&foreground, "white");
     }
-    
-    g_object_set (obj, "foreground-gdk", &foreground, 
+
+    g_object_set (obj, "foreground-gdk", &foreground,
                         "background-gdk", &background, NULL);
-                        
+
 }
 
 /* The following functions are taken from gedit and partially modified */
@@ -831,6 +887,13 @@ GList* editor_list_style_scheme_sorted (void) {
     GtkSourceStyleSchemeManager* manager =
         gtk_source_style_scheme_manager_get_default();
 
+    // add custom style path ~/.config/gummi/styles:
+    gchar* custom = g_build_path (G_DIR_SEPARATOR_S, C_GUMMI_CONFDIR, "styles", NULL);
+    if (g_file_test (custom, G_FILE_TEST_IS_DIR)) {
+        gtk_source_style_scheme_manager_append_search_path (manager, custom);
+    }
+    g_free (custom);
+
     scheme_ids = gtk_source_style_scheme_manager_get_scheme_ids (manager);
 
     while (*scheme_ids != NULL) {
