@@ -2,7 +2,7 @@
  * @file    gui-main.c
  * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -32,6 +32,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <sys/stat.h>
 
 #ifndef WIN32
 #   include <unistd.h>
@@ -42,6 +43,7 @@
 
 #include "biblio.h"
 #include "configfile.h"
+#include "constants.h"
 #include "editor.h"
 #include "environment.h"
 #include "importer.h"
@@ -61,18 +63,18 @@ extern GummiGui* gui;
  * http://www.micahcarrick.com/gtk-glade-tutorial-part-3.html */
 
 
-/* These widgets are (de-)sensitised using the gui_has_tabs_sensitive function
- * for when we switch from 0 to 1 tabs and vice versa */
+/* These widgets are (de)sensitised using the gui_set_hastabs_sensitive 
+ * function for when we switch from 0 to 1 tabs and vice versa */
 const gchar* insens_widgets_str[] = {
-    "rightpanebox", "tool_save", "tool_bold", "tool_italic", "tool_unline",
-    "tool_left", "tool_center", "tool_right", "menu_save", "menu_saveas",
-    "menu_exportpdf", "import_tabs", "menu_close", "menu_export", 
-    "menu_undo", "menu_redo", "menu_cut", "menu_copy", "menu_paste", 
+    "box_rightpane", "tool_save", "tool_bold", "tool_italic", "tool_unline",
+    "tool_left", "tool_center", "tool_right", "box_importers",
+    "menu_save", "menu_saveas", "menu_close", "menu_export",
+    "menu_undo", "menu_redo", "menu_cut", "menu_copy", "menu_paste",
     "menu_delete", "menu_selectall", "menu_preferences", "menu_find",
     "menu_prev", "menu_next", "menu_pdfcompile", "menu_compileopts",
     "menu_runmakeindex", "menu_runbibtex", "menu_docstat", "menu_spelling",
     "menu_snippets", "menu_edit", "menu_document", "menu_search",
-    "menu_cleanup"
+    "menu_cleanup", "menu_page_layout"
 };
 
 
@@ -83,17 +85,17 @@ GummiGui* gui_init (GtkBuilder* builder) {
     gint i = 0, wx = 0, wy = 0, width = 0, height = 0;
 
     GummiGui* g = g_new0 (GummiGui, 1);
-    
+
     g->builder = builder;
 
     g->mainwindow =
         GTK_WINDOW (gtk_builder_get_object (builder, "mainwindow"));
-    g->toolbar = 
+    g->toolbar =
         GTK_WIDGET (gtk_builder_get_object (builder, "maintoolbar"));
     g->statusbar =
         GTK_STATUSBAR (gtk_builder_get_object (builder, "statusbar"));
     g->rightpane =
-        GTK_VBOX (gtk_builder_get_object (builder, "rightpanebox"));
+        GTK_BOX (gtk_builder_get_object (builder, "box_rightpane"));
     g->previewoff = GTK_TOGGLE_TOOL_BUTTON (
             gtk_builder_get_object (builder, "tool_previewoff"));
     g->errorview =
@@ -125,7 +127,7 @@ GummiGui* gui_init (GtkBuilder* builder) {
 
     g->docstatswindow =
         GTK_WIDGET (gtk_builder_get_object (builder, "docstatswindow"));
-        
+
     g->menu_runbibtex =
         GTK_MENU_ITEM (gtk_builder_get_object (builder, "menu_runbibtex"));
     g->menu_runmakeindex =
@@ -153,21 +155,51 @@ GummiGui* gui_init (GtkBuilder* builder) {
     gchar* icon_file = g_build_filename (GUMMI_DATA, "icons", "icon.png", NULL);
     gtk_window_set_icon_from_file (g->mainwindow, icon_file, NULL);
     g_free (icon_file);
-    gtk_window_resize (g->mainwindow,
-                      atoi (config_get_value ("mainwindow_w")),
-                      atoi (config_get_value ("mainwindow_h")));
 
-    wx = atoi (config_get_value ("mainwindow_x"));
-    wy = atoi (config_get_value ("mainwindow_y"));
-    if (wx && wy)
-      gtk_window_move (g->mainwindow, wx, wy);
-    else
-      gtk_window_set_position (g->mainwindow, GTK_WIN_POS_CENTER);
+    // set main window size and positioning:
+    if (config_get_boolean ("Interface", "mainwindow_max")) {
+        gtk_window_maximize (g->mainwindow);
+    }
+    else {
+        gtk_window_resize (g->mainwindow,
+                           config_get_integer ("Interface", "mainwindow_w"),
+                           config_get_integer ("Interface", "mainwindow_h"));
+
+        wx = config_get_integer ("Interface", "mainwindow_x");
+        wy = config_get_integer ("Interface", "mainwindow_y");
+        if (wx && wy) {
+            gtk_window_move (g->mainwindow, wx, wy);
+        }
+        else {
+            gtk_window_set_position (g->mainwindow, GTK_WIN_POS_CENTER);
+        }
+    }
+
+    // use new css styling for errorview pane:
+    gtk_widget_set_name (GTK_WIDGET (g->errorview), "errorview");
+
+    GtkCssProvider *provider = gtk_css_provider_new ();
+    GError* error = NULL;
+
+    const gchar* css_data =
+        "#errorview {\n"
+        "   font: 12px 'Monospace';\n"
+        "}\n";
+
+    gtk_css_provider_load_from_data (provider, css_data, -1, &error);
+    if (error == NULL) {
+        GtkStyleContext *context;
+        context = gtk_widget_get_style_context (GTK_WIDGET (g->errorview));
+
+        gtk_style_context_add_provider (context,
+                                        GTK_STYLE_PROVIDER (provider),
+                                        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    }
+    else {
+        slog (L_ERROR, "%s\n", error->message);
+    }
+    g_object_unref (provider);
 
-    PangoFontDescription* font_desc =
-        pango_font_description_from_string ("Monospace 8");
-    gtk_widget_modify_font (GTK_WIDGET (g->errorview), font_desc);
-    pango_font_description_free (font_desc);
     gtk_window_get_size (g->mainwindow, &width, &height);
 
     hpaned= GTK_WIDGET (gtk_builder_get_object (builder, "hpaned"));
@@ -176,57 +208,57 @@ GummiGui* gui_init (GtkBuilder* builder) {
 #ifndef USE_GTKSPELL
     gtk_widget_set_sensitive (GTK_WIDGET (g->menu_spelling), FALSE);
 #else
-    if (config_get_value ("spelling"))
+    if (config_get_boolean ("Editor", "spelling"))
         gtk_check_menu_item_set_active (g->menu_spelling, TRUE);
 #endif
-    if (config_get_value ("snippets")) {
+    if (config_get_boolean ("Interface", "snippets")) {
         gtk_check_menu_item_set_active (g->menu_snippets, TRUE);
         gtk_widget_show (GTK_WIDGET (g->menu_snippets));
     }
-    if (config_get_value ("toolbar")) {
+    if (config_get_boolean ("Interface", "toolbar")) {
         gtk_check_menu_item_set_active (g->menu_toolbar, TRUE);
         gtk_widget_show (g->toolbar);
     } else {
-        config_set_value ("toolbar", "False");
+        config_set_boolean ("Interface", "toolbar", FALSE);
         gtk_check_menu_item_set_active (g->menu_toolbar, FALSE);
         gtk_widget_hide (g->toolbar);
     }
 
-    if (config_get_value ("statusbar")) {
+    if (config_get_boolean ("Interface", "statusbar")) {
         gtk_check_menu_item_set_active (g->menu_statusbar, TRUE);
         gtk_widget_show (GTK_WIDGET (g->statusbar));
     } else {
-        config_set_value ("statusbar", "False");
+        config_set_boolean ("Interface", "statusbar", FALSE);
         gtk_check_menu_item_set_active (g->menu_statusbar, FALSE);
         gtk_widget_hide (GTK_WIDGET (g->statusbar));
     }
 
-    if (config_get_value ("rightpane")) {
+    if (config_get_boolean ("Interface", "rightpane")) {
         gtk_check_menu_item_set_active (g->menu_rightpane, TRUE);
         gtk_widget_show (GTK_WIDGET (g->rightpane));
     } else {
-        config_set_value ("compile_status", "False");
+        config_set_boolean ("Compile", "status", FALSE);
         gtk_toggle_tool_button_set_active (g->previewoff, FALSE);
         gtk_widget_hide (GTK_WIDGET (g->rightpane));
     }
-    
-    g->menu_autosync = 
+
+    g->menu_autosync =
         GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu_autosync"));
-    
-    if (latex_can_synctex() && config_get_value ("synctex")) {
+
+    if (latex_can_synctex() && config_get_boolean ("Compile", "synctex")) {
         gtk_widget_set_sensitive (GTK_WIDGET (g->menu_autosync), TRUE);
         gboolean async = latex_use_synctex();
         gtk_check_menu_item_set_active (g->menu_autosync, (async? TRUE: FALSE));
     }
-        
-    if (!config_get_value ("compile_status"))
+
+    if (!config_get_boolean ("Compile", "status"))
         gtk_toggle_tool_button_set_active (g->previewoff, TRUE);
 
-    g->recent_list[0] = g_strdup (config_get_value ("recent1"));
-    g->recent_list[1] = g_strdup (config_get_value ("recent2"));
-    g->recent_list[2] = g_strdup (config_get_value ("recent3"));
-    g->recent_list[3] = g_strdup (config_get_value ("recent4"));
-    g->recent_list[4] = g_strdup (config_get_value ("recent5"));
+    g->recent_list[0] = g_strdup (config_get_string ("Misc", "recent1"));
+    g->recent_list[1] = g_strdup (config_get_string ("Misc", "recent2"));
+    g->recent_list[2] = g_strdup (config_get_string ("Misc", "recent3"));
+    g->recent_list[3] = g_strdup (config_get_string ("Misc", "recent4"));
+    g->recent_list[4] = g_strdup (config_get_string ("Misc", "recent5"));
 
     display_recent_files (g);
 
@@ -247,14 +279,14 @@ gboolean w32popup_wait_event (void *builder) {
 
 	const gchar* count = gtk_label_get_text (GTK_LABEL (gui->w32label));
 	gint number = atoi (count) - 1;
-	
+
 	if (number == 0) {
 
-		gtk_label_set_text (GTK_LABEL (gui->w32label), "");	
+		gtk_label_set_text (GTK_LABEL (gui->w32label), "");
 		gtk_widget_set_sensitive (gui->w32button, TRUE);
 		return FALSE;
 	}
-	gtk_label_set_text (GTK_LABEL (gui->w32label), 
+	gtk_label_set_text (GTK_LABEL (gui->w32label),
 						g_strdup_printf("%d", number));
 	return TRUE;
 }
@@ -265,20 +297,18 @@ void gui_main (GtkBuilder* builder) {
     gtk_widget_show_all (GTK_WIDGET (gui->mainwindow));
 
 	#ifdef WIN32
-    gui->w32window = 
+    gui->w32window =
 			GTK_WIDGET (gtk_builder_get_object (builder, "w32popup"));
-	gui->w32button = 
+	gui->w32button =
 			GTK_WIDGET (gtk_builder_get_object (builder, "w32button"));
-	gui->w32label = 
+	gui->w32label =
 			GTK_WIDGET (gtk_builder_get_object (builder, "w32label"));
     gtk_widget_show (gui->w32window);
-    
+
     g_timeout_add_seconds (1, w32popup_wait_event, NULL);
     #endif
 
-    gdk_threads_enter();
     gtk_main ();
-    gdk_threads_leave();
 }
 
 
@@ -286,15 +316,14 @@ void gui_main (GtkBuilder* builder) {
 G_MODULE_EXPORT
 void on_menu_autosync_toggled (GtkCheckMenuItem *menu_autosync, void* user) {
     if (gtk_check_menu_item_get_active(menu_autosync)) {
-        config_set_value("autosync", "True");
+        config_set_boolean ("Preview", "autosync", TRUE);
     } else {
-        config_set_value("autosync", "False");
+        config_set_boolean ("Preview", "autosync", FALSE);
     }
 }
 
 G_MODULE_EXPORT
-void on_tab_notebook_switch_page(GtkNotebook *notebook, GtkWidget *nbpage,
-                                 int pagenr, void *data) {
+void on_tab_notebook_switch_page (GtkNotebook *notebook, GtkWidget *nbpage, int pagenr, void *data) {
     slog (L_DEBUG, "Switched to environment at page %d\n", pagenr);
     /* Kill typesetter command */
     motion_kill_typesetter(gummi->motion);
@@ -304,10 +333,10 @@ void on_tab_notebook_switch_page(GtkNotebook *notebook, GtkWidget *nbpage,
 
     /* update the title of the mainwindow */
     gui_set_filename_display (g_active_tab, TRUE, FALSE);
-    
+
     /* clear the build log output window */
     gui_buildlog_set_text ("");
-    
+
     previewgui_reset (gui->previewgui);
 }
 
@@ -326,7 +355,7 @@ void on_right_notebook_switch_page(GtkNotebook *notebook, GtkWidget *nbpage,
 
 void gui_set_filename_display (GuTabContext* tc, gboolean title, gboolean label) {
     gchar* filetext = tabmanager_get_tabname (tc);
-    
+
     if (label) tabmanagergui_update_label (tc->page, filetext);
     if (title) gui_set_window_title (tc->editor->filename, filetext);
 }
@@ -338,20 +367,18 @@ void gui_set_window_title (const gchar* filename, const gchar* text) {
     if (filename != NULL) {
         dirname = g_strdup_printf("(%s)", g_path_get_dirname (filename));
         title = g_strdup_printf ("%s %s - %s", text, dirname,
-                                                 PACKAGE_NAME);
+                                                 C_PACKAGE_NAME);
     }
     else {
-        title = g_strdup_printf ("%s - %s", text, PACKAGE_NAME);
+        title = g_strdup_printf ("%s - %s", text, C_PACKAGE_NAME);
     }
     gtk_window_set_title (gui->mainwindow, title);
     g_free (title);
 }
 
-
-
 void on_recovery_infobar_response (GtkInfoBar* bar, gint res, gpointer filename) {
     gchar* prev_workfile = iofunctions_get_swapfile (filename);
-    
+
     if (res == GTK_RESPONSE_YES) {
         tabmanager_set_content (A_LOAD_OPT, filename, prev_workfile);
     }
@@ -369,12 +396,12 @@ void gui_recovery_mode_enable (GuTabContext* tab, const gchar* filename) {
 				"do you want to recover from it?"), filename);
     gtk_label_set_text (GTK_LABEL (tab->page->barlabel), msg);
     g_free (msg);
-    
+
     gchar* data = g_strconcat (filename, NULL);
-    tab->page->infosignal = 
+    tab->page->infosignal =
         g_signal_connect (g_active_tab->page->infobar, "response",
         G_CALLBACK (on_recovery_infobar_response), (gpointer)data);
-        
+
     gtk_widget_set_sensitive (GTK_WIDGET (tab->editor->view), FALSE);
     gtk_widget_show (tab->page->infobar);
 }
@@ -422,17 +449,40 @@ void gui_save_file (GuTabContext* tab, gboolean saveas) {
             }
         } else goto cleanup;
     }
-    
+
     gchar *text;
     GtkWidget* focus = NULL;
 
+    // check whether the file has been changed by (some) external program
+    double lastmod;
+    struct stat attr;
+    stat(filename, &attr);
+    lastmod = difftime (tab->editor->last_modtime, attr.st_mtime);
+
+    if (lastmod != 0.0 && tab->editor->last_modtime != 0.0 ) {
+        // ask the user whether he want to save or reload
+        ret = utils_save_reload_dialog (
+                _("The content of the file has been changed externally. "
+                  "Saving will remove any external modifications."));
+        if (ret == GTK_RESPONSE_YES) {
+            tabmanager_set_content (A_LOAD, filename, NULL);
+            // resets modtime
+            stat(filename, &attr);
+            tab->editor->last_modtime = attr.st_mtime;
+            goto cleanup;
+        } else if (ret != GTK_RESPONSE_NO) {
+            // cancel means: do nothing
+            goto cleanup;
+        }
+    }
+
     focus = gtk_window_get_focus (gummi_get_gui ()->mainwindow);
     text = editor_grab_buffer (tab->editor);
     gtk_widget_grab_focus (focus);
-    
+
     iofunctions_save_file (gummi->io, filename, text);
 
-    if (config_get_value ("autoexport")) {
+    if (config_get_boolean ("File", "autoexport")) {
         pdfname = g_strdup (filename);
         pdfname[strlen (pdfname) -4] = 0;
         latex_export_pdffile (gummi->latex, tab->editor, pdfname, FALSE);
@@ -441,6 +491,10 @@ void gui_save_file (GuTabContext* tab, gboolean saveas) {
     gui_set_filename_display (tab, TRUE, TRUE);
     gtk_widget_grab_focus (GTK_WIDGET (tab->editor->view));
 
+    // Resets modtime
+    stat(filename, &attr);
+    tab->editor->last_modtime = attr.st_mtime;
+
 cleanup:
     if (new) g_free (filename);
     g_free (pdfname);
@@ -448,8 +502,9 @@ cleanup:
 
 void gui_set_hastabs_sensitive (gboolean enable) {
     gint i = 0;
-    for (i = 0; i < gui->insens_widget_size; ++i)
+    for (i = 0; i < gui->insens_widget_size; ++i) {
         gtk_widget_set_sensitive (gui->insens_widgets[i], enable);
+    }
 }
 
 G_MODULE_EXPORT
@@ -467,7 +522,9 @@ G_MODULE_EXPORT
 void on_tool_previewoff_toggled (GtkWidget *widget, void * user) {
     gboolean value =
         gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (widget));
-    config_set_value ("compile_status", (!value)? "True": "False");
+
+    config_set_boolean ("Compile", "status", value);
+
     if (value)
         previewgui_stop_preview (gui->previewgui);
     else
@@ -529,7 +586,7 @@ void on_button_template_open_clicked (GtkWidget* widget, void* user) {
         gtk_widget_hide (GTK_WIDGET (gummi->templ->templatewindow));
     }
     g_free(templ_name);
-    
+
     if (!gtk_widget_get_sensitive (GTK_WIDGET (gui->rightpane)))
         gui_set_hastabs_sensitive (TRUE);
 }
@@ -565,13 +622,13 @@ void on_template_rowitem_edited (GtkWidget* widget, gchar *path, gchar* filenm,
     g_free (filepath);
 }
 
-G_MODULE_EXPORT 
+G_MODULE_EXPORT
 void on_template_cursor_changed (GtkTreeView *tree, gpointer data) {
     if (!gtk_tree_view_get_selection (tree) == 0) {
         gtk_widget_set_sensitive (gummi->templ->template_open, TRUE);
     }
 }
-    
+
 
 G_MODULE_EXPORT
 void on_bibcolumn_clicked (GtkWidget* widget, void* user) {
@@ -584,21 +641,23 @@ void on_bibcolumn_clicked (GtkWidget* widget, void* user) {
 G_MODULE_EXPORT
 void on_button_biblio_compile_clicked (GtkWidget* widget, void* user) {
     gummi->biblio->progressval = 0.0;
-    
+
     gtk_widget_set_sensitive (widget, FALSE);
-    g_timeout_add (10, on_bibprogressbar_update, NULL);
+    g_timeout_add (10, on_bibprogressbar_update, widget);
 
     if (biblio_compile_bibliography (gummi->biblio, g_active_editor,
                 gummi->latex)) {
-        statusbar_set_message (_("Compiling bibliography file..."));
-        gtk_progress_bar_set_text (gummi->biblio->progressbar,
-                _("Bibliography compiled without errors"));
+        statusbar_set_message (_("Compiling bibliography file.."));
+        // NOTE gtk3s bar doesnt place text inside the widget anymore :/
+        //gtk_progress_bar_set_text (gummi->biblio->progressbar,
+        //        _("Bibliography compiled without errors"));
         motion_force_compile (gummi->motion);
     } else {
-        statusbar_set_message 
-        (_("Error compiling bibliography file or none detected..."));
-        gtk_progress_bar_set_text (gummi->biblio->progressbar,
-                _("Error compiling bibliography file"));
+        statusbar_set_message
+        (_("Error compiling bibliography file or none detected.."));
+        // NOTE gtk3s bar doesnt place text inside the widget anymore :/
+        //gtk_progress_bar_set_text (gummi->biblio->progressbar,
+        //        _("Error compiling bibliography file"));
     }
 }
 
@@ -611,7 +670,7 @@ void on_button_biblio_detect_clicked (GtkWidget* widget, void* user) {
     gint number = 0;
 
     gummi->biblio->progressval = 0.0;
-    g_timeout_add (2, on_bibprogressbar_update, NULL);
+    g_timeout_add (2, on_bibprogressbar_update, widget);
     gtk_list_store_clear (gummi->biblio->list_biblios);
 
     if (biblio_detect_bibliography (gummi->biblio, g_active_editor)) {
@@ -631,16 +690,18 @@ void on_button_biblio_detect_clicked (GtkWidget* widget, void* user) {
         str = g_strdup_printf ("%d", number);
         gtk_label_set_text (gummi->biblio->refnr_label, str);
         g_free (str);
-        str = g_strdup_printf (_("%s loaded"), basename);
-        gtk_progress_bar_set_text (gummi->biblio->progressbar, str);
+        // NOTE gtk3s bar doesnt place text inside the widget anymore :/
+        //gtk_progress_bar_set_text (gummi->biblio->progressbar, str);
         g_free (basename);
-        g_free (str);
     }
     else {
         gtk_widget_set_sensitive
                     (GTK_WIDGET(gummi->biblio->list_filter), FALSE);
-        gtk_progress_bar_set_text (gummi->biblio->progressbar,
-                _("no bibliography file detected"));
+        statusbar_set_message
+        (_("No bibliography file detected in document.."));
+        // NOTE gtk3s bar doesnt place text inside the widget anymore :/
+        //gtk_progress_bar_set_text (gummi->biblio->progressbar,
+        //        _("no bibliography file detected"));
         gtk_label_set_text (gummi->biblio->filenm_label, _("none"));
         gtk_label_set_text (gummi->biblio->refnr_label, _("N/A"));
     }
@@ -704,29 +765,29 @@ void typesetter_setup (void) {
     gtk_widget_set_sensitive (GTK_WIDGET (gui->menu_runmakeindex), status);
     gtk_widget_set_sensitive (GTK_WIDGET (gui->prefsgui->opt_shellescape),
                               status);
-                              
+
     gboolean texormk = (texlive_active() || latexmk_active());
-    
-    
-    
-    if (config_get_value("synctex") && texormk) {
+
+    if (config_get_boolean ("Compile", "synctex") && texormk) {
         gtk_toggle_button_set_active (gui->prefsgui->opt_synctex, TRUE);
     }
     else {
         gtk_toggle_button_set_active (gui->prefsgui->opt_synctex, FALSE);
     }
     gtk_widget_set_sensitive (GTK_WIDGET (gui->prefsgui->opt_synctex), texormk);
-    
-    
-    slog (L_INFO, "Typesetter %s configured.\n",config_get_value("typesetter"));
+
+    slog (L_INFO, "Typesetter %s configured\n",
+                   config_get_string ("Compile", "typesetter"));
 }
 
-gboolean on_bibprogressbar_update (void* user) {
-    gtk_adjustment_set_value
-        (gummi->biblio->progressmon, gummi->biblio->progressval);
-    gummi->biblio->progressval += 1.0;
-    if (gummi->biblio->progressval > 60) {
-        gtk_widget_set_sensitive (gui->bibcompile, TRUE);
+gboolean on_bibprogressbar_update (void* data) {
+    gummi->biblio->progressval += 0.01;
+
+    gtk_progress_bar_set_fraction(gummi->biblio->progressbar,
+                                  gummi->biblio->progressval);
+
+    if (gummi->biblio->progressval >= 1) {
+        gtk_widget_set_sensitive (data, TRUE);
         return FALSE;
     }
     return TRUE;
@@ -735,26 +796,29 @@ gboolean on_bibprogressbar_update (void* user) {
 gint check_for_save (GuEditor* editor) {
     GtkWidget* dialog;
     gint ret = 0;
-    
+
     if (editor && editor_buffer_changed (editor)){
         dialog = gtk_message_dialog_new (gui->mainwindow,
                      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                      GTK_MESSAGE_QUESTION,
                      GTK_BUTTONS_NONE,
-                     _("Do you want to save the changes to %s?"),
-                     editor->filename != NULL ? g_path_get_basename (editor->filename) : _("this document"));
+                     _("This document has unsaved changes"));
+
+        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                    _("Do you want to save the changes to %s before closing?"),
+                                     editor->filename != NULL ? g_path_get_basename (editor->filename) : _("this document"));
+
         gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                GTK_STOCK_DISCARD, GTK_RESPONSE_NO,
-                                GTK_STOCK_SAVE, GTK_RESPONSE_YES,
+                                _("_Close without Saving"), GTK_RESPONSE_NO,
+                                _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                _("_Save As"), GTK_RESPONSE_YES,
                                 NULL);
+
         gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
-        
-        gtk_window_set_title (GTK_WINDOW (dialog), _("Unsaved Changes"));
+
         ret = gtk_dialog_run (GTK_DIALOG (dialog));
         gtk_widget_destroy (dialog);
     }
-    
     return ret;
 }
 
@@ -776,15 +840,16 @@ gchar* get_open_filename (GuFilterType type) {
         "shouldn't happen",
         "shouldn't happen",
         _("Select an image to insert"),
-        _("Select bibliography file")
+        _("Select bibliography file"),
+        _("Select project file")
     };
 
     chooser = GTK_FILE_CHOOSER (gtk_file_chooser_dialog_new (
                 chooser_title[type],
                 gui->mainwindow,
                 GTK_FILE_CHOOSER_ACTION_OPEN,
-                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+                _("_Cancel"), GTK_RESPONSE_CANCEL,
+                _("_Open"), GTK_RESPONSE_OK,
                 NULL));
 
     file_dialog_set_filter (chooser, type);
@@ -821,8 +886,8 @@ gchar* get_save_filename (GuFilterType type) {
                 chooser_title[type],
                 gui->mainwindow,
                 GTK_FILE_CHOOSER_ACTION_SAVE,
-                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+                _("_Cancel"), GTK_RESPONSE_CANCEL,
+                _("_Save"), GTK_RESPONSE_OK,
                 NULL));
 
     file_dialog_set_filter (chooser, type);
@@ -863,10 +928,6 @@ void file_dialog_set_filter (GtkFileChooser* dialog, GuFilterType type) {
             gtk_file_filter_add_pattern (filter, "*.tex");
             gtk_file_chooser_add_filter (dialog, filter);
             gtk_file_chooser_set_filter (dialog, filter);
-            filter = gtk_file_filter_new ();
-            gtk_file_filter_set_name (filter, _("Text files"));
-            gtk_file_filter_add_mime_type (filter, "text/plain");
-            gtk_file_chooser_add_filter (dialog, filter);
             break;
 
         case TYPE_PDF:
@@ -876,12 +937,12 @@ void file_dialog_set_filter (GtkFileChooser* dialog, GuFilterType type) {
             gtk_file_chooser_set_filter (dialog, filter);
             break;
 
-        case TYPE_IMAGE: 
-            /* Only \insertgraphics uses this section now. Make sure 
+        case TYPE_IMAGE:
+            /* Only \insertgraphics uses this section now. Make sure
              * the patterns & mimes are correct before assigning it
 			 * for other functions */
             gtk_file_filter_set_name (filter, _("Supported Image files"));
-            
+
             /* Pdflatex supports different formats than pure latex */
             if (latex_method_active ("texpdf")) {
 				gtk_file_filter_add_pattern (filter, "*.jpg");
@@ -905,7 +966,7 @@ void file_dialog_set_filter (GtkFileChooser* dialog, GuFilterType type) {
             gtk_file_filter_add_pattern (filter, "*.gummi");
             gtk_file_chooser_add_filter (dialog, filter);
             gtk_file_chooser_set_filter (dialog, filter);
-            break;   
+            break;
     }
 }
 
@@ -946,10 +1007,10 @@ void display_recent_files (GummiGui* gui) {
             ++count;
         }
     }
-    /* update recent files */
+    // update recent files
     for (i = 0; i < RECENT_FILES_NUM; ++i) {
         tstr = g_strdup_printf ("recent%d", i + 1);
-        config_set_value (tstr, gui->recent_list[i]);
+        config_set_string ("Misc", tstr, gui->recent_list[i]);
         g_free (tstr);
     }
 }
@@ -957,13 +1018,14 @@ void display_recent_files (GummiGui* gui) {
 void gui_buildlog_set_text (const gchar *message) {
     if (message) {
         GtkTextIter iter;
+        GtkTextMark *mark;
+        
         gtk_text_buffer_set_text (gui->errorbuff, message, -1);
         gtk_text_buffer_get_end_iter (gui->errorbuff, &iter);
-		// The following lines are commented out, as they seem to cause 
-		// Bug #252.
-        //GtkTextMark *mark = gtk_text_buffer_create_mark(gui->errorbuff, NULL, &iter, FALSE);
-        //gtk_text_view_scroll_to_mark (gui->errorview, mark, 0.25, FALSE, 0, 0);
-        //gtk_text_view_scroll_to_iter (gui->errorview, &iter, 0.25, FALSE, 0, 0);
+        
+        // scrolling to the end used to cause bug #252 but seems ok now:
+        mark = gtk_text_buffer_create_mark(gui->errorbuff, NULL, &iter, FALSE);
+        gtk_text_view_scroll_to_mark (gui->errorview, mark, 0.25, FALSE, 0, 0);
     }
 }
 
@@ -984,10 +1046,10 @@ gboolean statusbar_del_message (void* user) {
  */
 void check_preview_timer (void) {
     g_return_if_fail (g_active_tab != NULL);
-    
+
     gtk_text_buffer_set_modified (g_e_buffer, TRUE);
     gummi->latex->modified_since_compile = TRUE;
-    
+
     gui_set_filename_display (g_active_tab, TRUE, TRUE);
 
     motion_start_timer (gummi->motion);
