@@ -1,10 +1,10 @@
 /**
  * @file   gui-main.h
- * @brief   
+ * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
- * 
+ *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
  * files (the "Software"), to deal in the Software without
@@ -47,9 +47,9 @@
 #define RECENT_FILES_NUM 5
 #define TEXCOUNT_OUTPUT_LINES 7
 
-/* These macros should be only used in GUI related classes 
+/* These macros should be only used in GUI related classes
  * which acted as syntax sugar */
-/* These macros should be only used in GUI related classes 
+/* These macros should be only used in GUI related classes
  * which acted as syntax sugar */
 #define g_e_buffer GTK_TEXT_BUFFER (g_active_editor->buffer)
 #define g_e_view GTK_TEXT_VIEW (g_active_editor->view)
@@ -59,7 +59,7 @@
 
 
 #define GUMMI_GUI(x) ((GummiGui*)x)
-typedef struct _GummiGui GummiGui; 
+typedef struct _GummiGui GummiGui;
 
 struct _GummiGui {
     GuMenuGui* menugui;
@@ -75,7 +75,7 @@ struct _GummiGui {
     GtkWindow* mainwindow;
     GtkTextBuffer* errorbuff;
     GtkTextView* errorview;
-        GtkVBox* rightpane;
+    GtkBox* rightpane;
 
     GtkWidget* toolbar;
     GtkStatusbar* statusbar;
@@ -92,16 +92,16 @@ struct _GummiGui {
     GtkBuilder *builder;
     GtkWidget *docstatswindow;
     GtkWidget *bibcompile;
-    
+
     GtkMenuItem* menu_runbibtex;
     GtkMenuItem* menu_runmakeindex;
-    
+
     #ifdef WIN32
 		GtkWidget* w32label;
 		GtkWidget* w32button;
 		GtkWidget* w32window;
     #endif
-    
+
     guint statusid;
     gchar* recent_list[5];
 };
@@ -121,7 +121,7 @@ void gui_main (GtkBuilder* builder);
 gboolean gui_quit (void);
 
 
-void gui_set_filename_display (GuTabContext* tc, 
+void gui_set_filename_display (GuTabContext* tc,
                                         gboolean title, gboolean label);
 void gui_set_window_title (const gchar* filename, const gchar* text);
 
@@ -130,8 +130,7 @@ void gui_open_file (const gchar* filename);
 void gui_save_file (GuTabContext* tab, gboolean saveas);
 void gui_set_hastabs_sensitive (gboolean enable);
 
-void on_tab_notebook_switch_page(GtkNotebook *notebook, GtkWidget* nbpage,
-        int page, void* data);
+void on_tab_notebook_switch_page (GtkNotebook *notebook, GtkWidget* nbpage, int pagenr, void* data);
 void on_tool_previewoff_toggled (GtkWidget *widget, void * user);
 void on_tool_textstyle_bold_activate (GtkWidget* widget, void* user);
 void on_tool_textstyle_italic_activate (GtkWidget* widget, void* user);
@@ -153,7 +152,7 @@ void on_button_biblio_detect_clicked (GtkWidget* widget, void* user);
 void on_bibreference_clicked (GtkTreeView* view, GtkTreePath* Path,
         GtkTreeViewColumn* column, void* user);
 void on_biblio_filter_changed (GtkWidget* widget, void* user);
-gboolean on_bibprogressbar_update (void* user);
+gboolean on_bibprogressbar_update (void* data);
 
 void on_recovery_infobar_response (GtkInfoBar* bar, gint res, gpointer filename);
 void gui_recovery_mode_enable (GuTabContext* tab, const gchar* filename);
