@@ -2,7 +2,7 @@
  * @file   gui-menu.c
  * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -34,10 +34,11 @@
 #include "editor.h"
 #include "environment.h"
 #include "external.h"
-#include "gui-main.h"
-#include "motion.h"
 #include "project.h"
-#include "update.h"
+
+#include "gui-main.h"
+#include "gui-preview.h"
+
 
 extern Gummi* gummi;
 extern GummiGui* gui;
@@ -49,44 +50,46 @@ GuMenuGui* menugui_init (GtkBuilder* builder) {
     g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
 
     GuMenuGui* m = g_new0 (GuMenuGui, 1);
-    
+
     m->menu_projcreate = GTK_MENU_ITEM(
                         gtk_builder_get_object (builder, "menu_projcreate"));
     m->menu_projopen = GTK_MENU_ITEM(
                         gtk_builder_get_object (builder, "menu_projopen"));
     m->menu_projclose = GTK_MENU_ITEM(
                         gtk_builder_get_object (builder, "menu_projclose"));
-    
+    m->menu_cut = GTK_MENU_ITEM(gtk_builder_get_object (builder, "menu_cut"));
+    m->menu_copy = GTK_MENU_ITEM(gtk_builder_get_object (builder, "menu_copy"));
+
     #ifdef WIN32
     // Please do NOT enable for nix, it has no place on a free OS ;)
-    GtkWidget* donate = 
+    GtkWidget* donate =
 		gtk_image_menu_item_new_with_label ("Support this Project");
-    gtk_image_menu_item_set_image 
-        (GTK_IMAGE_MENU_ITEM(donate), 
+    gtk_image_menu_item_set_image
+        (GTK_IMAGE_MENU_ITEM(donate),
          GTK_WIDGET(gtk_image_new_from_stock(
          GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_MENU)));
-    GtkWidget* helpmenu = 
+    GtkWidget* helpmenu =
 		GTK_WIDGET (gtk_builder_get_object (builder, "menu11"));
     gtk_menu_prepend (GTK_MENU (helpmenu), donate);
     gtk_signal_connect_object (GTK_OBJECT (donate), "activate",
                                GTK_SIGNAL_FUNC (on_menu_donate_activate),
                                NULL);
     #endif
-    
+
     /* TODO: There has to be a better way than this.. (bug 246)
     GtkSettings *settings = gtk_settings_get_default();
     gchar *iconsizes;
     g_object_get(settings, "gtk-icon-sizes", &iconsizes, NULL);
     if (iconsizes != NULL) {
         printf("%s\n", iconsizes);
-    }*/ 
+    }*/
 
     #ifdef WIN32
-        // The 2 non-stock menu items have their pixel size values set 
-        // to the default 16x16 in GLADE. The normal icon-size value is 
+        // The 2 non-stock menu items have their pixel size values set
+        // to the default 16x16 in GLADE. The normal icon-size value is
         // normally set by the GTK theme in gtkrc. For themes using
         // non-default icon sizes or Windows, this 16x16 value will be
-        // wrong. This code sets it to match the gtkrc file that we 
+        // wrong. This code sets it to match the gtkrc file that we
         // supply with the Windows builds:
         GtkWidget* export = gtk_image_menu_item_get_image (
         GTK_IMAGE_MENU_ITEM (gtk_builder_get_object (builder, "menu_export")));
@@ -95,10 +98,10 @@ GuMenuGui* menugui_init (GtkBuilder* builder) {
         gtk_image_set_pixel_size (GTK_IMAGE(export), 13);
         gtk_image_set_pixel_size (GTK_IMAGE(update), 13);
     #endif
- 
 
-    
-    
+
+
+
     return m;
 }
 
@@ -107,7 +110,7 @@ G_MODULE_EXPORT
 void on_menu_donate_activate (GtkWidget* widget, void* user) {
 	//TODO: enhance
 	GtkWidget* dialog;
-    dialog = gtk_message_dialog_new (gui->mainwindow, 
+    dialog = gtk_message_dialog_new (gui->mainwindow,
         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
         GTK_MESSAGE_INFO,
         GTK_BUTTONS_OK,
@@ -117,7 +120,7 @@ void on_menu_donate_activate (GtkWidget* widget, void* user) {
         "project with a donation, please visit our official website. "
         "Thank you!");
     gtk_window_set_title (GTK_WINDOW (dialog), "Support this project");
-    gtk_dialog_run (GTK_DIALOG (dialog));      
+    gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 }
 #endif
@@ -202,35 +205,35 @@ void on_menu_recent_activate (GtkWidget *widget, void *user) {
 G_MODULE_EXPORT
 void on_menu_close_activate (GtkWidget *widget, void* user) {
     GuTabContext* tab = NULL;
-    
+
     tab = (user)? GU_TAB_CONTEXT (user): g_active_tab;
-    
+
     gint ret = check_for_save (tab->editor);
-    
+
     if (GTK_RESPONSE_YES == ret)
         gui_save_file (tab, FALSE);
     else if (GTK_RESPONSE_CANCEL == ret || GTK_RESPONSE_DELETE_EVENT == ret)
         return;
-    
-    /* Kill typesetter command */
+
+    // kill typesetter thread
     motion_kill_typesetter(gummi->motion);
 
-    if (!tabmanager_remove_tab (tab)) {
-        motion_start_errormode (gummi->motion, "");
+    // remove tab:
+    gint remaining_tabs = tabmanager_remove_tab (tab);
+    if (remaining_tabs == 0) {
+        previewgui_start_errormode (gui->previewgui, "");
         gui_set_hastabs_sensitive (FALSE);
-    } else {
+    }
+    else {
         gui_set_filename_display (g_active_tab, TRUE, FALSE);
     }
 }
 
 G_MODULE_EXPORT
 gboolean on_menu_quit_activate (void) {
-    gint wx = 0, wy = 0, width = 0, height = 0;
-    gchar buf[16];
-    int i = 0;
     gint length = g_list_length (gummi->tabmanager->tabs);
+    int i = 0;
 
-    motion_pause_compile_thread (gummi->motion);
     for(i = 0; i < length; i++){
         gtk_notebook_set_current_page(gui->tabmanagergui->notebook, i);
         tabmanager_set_active_tab (i);
@@ -242,18 +245,24 @@ gboolean on_menu_quit_activate (void) {
             return TRUE;
     }
 
-    /* Stop compile thread */
+    // stop compile thread
     if (length > 0) motion_stop_compile_thread (gummi->motion);
 
-    gtk_window_get_size (gui->mainwindow, &width, &height);
-    gtk_window_get_position (gui->mainwindow, &wx, &wy);
+    // save current window size/position to persistent config
+    if (gtk_window_is_maximized (gui->mainwindow)) {
+        config_set_boolean ("Interface", "mainwindow_max", TRUE);
+    }
+    else { // unmaximized mainwindow:
+        gint wx = 0, wy = 0, width = 0, height = 0;
+        gtk_window_get_size (gui->mainwindow, &width, &height);
+        gtk_window_get_position (gui->mainwindow, &wx, &wy);
 
-    config_begin();
-    config_set_value ("mainwindow_x", g_ascii_dtostr (buf, 16, (double)wx));
-    config_set_value ("mainwindow_y", g_ascii_dtostr (buf, 16, (double)wy));
-    config_set_value ("mainwindow_w", g_ascii_dtostr (buf, 16, (double)width));
-    config_set_value ("mainwindow_h", g_ascii_dtostr (buf, 16, (double)height));
-    config_commit();
+        config_set_boolean ("Interface", "mainwindow_max", FALSE);
+        config_set_integer ("Interface", "mainwindow_x", wx);
+        config_set_integer ("Interface", "mainwindow_y", wy);
+        config_set_integer ("Interface", "mainwindow_w", width);
+        config_set_integer ("Interface", "mainwindow_h", height);
+    }
 
     gtk_main_quit ();
 
@@ -264,7 +273,7 @@ gboolean on_menu_quit_activate (void) {
     printf ("   ___ \n"
             "  {o,o}    Thanks for using Gummi!\n"
             "  |)__)    I welcome your feedback at:\n"
-            "  -\"-\"-    http://gummi.midnightcoding.org\n\n");
+            "  -\"-\"-    https://github.com/alexandervdm/gummi\n\n");
     return FALSE;
 }
 
@@ -272,6 +281,22 @@ gboolean on_menu_quit_activate (void) {
  * EDIT MENU                                                                   *
  ******************************************************************************/
 
+G_MODULE_EXPORT
+void on_menu_edit_activate (GtkWidget *widget, void *user) {
+    if (g_active_editor == NULL)
+        return;
+
+    if (gtk_text_buffer_get_has_selection
+	(GTK_TEXT_BUFFER(g_active_editor->buffer))) {
+        gtk_widget_set_sensitive (GTK_WIDGET (gui->menugui->menu_cut), TRUE);
+        gtk_widget_set_sensitive (GTK_WIDGET (gui->menugui->menu_copy), TRUE);
+        return;
+    }
+
+    gtk_widget_set_sensitive (GTK_WIDGET (gui->menugui->menu_cut), FALSE);
+    gtk_widget_set_sensitive (GTK_WIDGET (gui->menugui->menu_copy), FALSE);
+}
+
 G_MODULE_EXPORT
 void on_menu_undo_activate (GtkWidget *widget, void* user) {
     editor_undo_change (g_active_editor);
@@ -332,10 +357,10 @@ G_MODULE_EXPORT
 void on_menu_statusbar_toggled (GtkWidget *widget, void *user) {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) {
         gtk_widget_show (GTK_WIDGET (gui->statusbar));
-        config_set_value ("statusbar", "True");
+        config_set_boolean ("Interface", "statusbar", TRUE);
     } else {
         gtk_widget_hide (GTK_WIDGET (gui->statusbar));
-        config_set_value ("statusbar", "False");
+        config_set_boolean ("Interface", "statusbar", FALSE);
     }
 }
 
@@ -343,10 +368,10 @@ G_MODULE_EXPORT
 void on_menu_toolbar_toggled (GtkWidget *widget, void *user) {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) {
         gtk_widget_show (gui->toolbar);
-        config_set_value ("toolbar", "True");
+        config_set_boolean ("Interface", "toolbar", TRUE);
     } else {
         gtk_widget_hide (gui->toolbar);
-        config_set_value ("toolbar", "False");
+        config_set_boolean ("Interface", "toolbar", FALSE);
     }
 }
 
@@ -354,11 +379,11 @@ G_MODULE_EXPORT
 void on_menu_rightpane_toggled (GtkWidget *widget, void *user) {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) {
         gtk_widget_show (GTK_WIDGET (gui->rightpane));
-        config_set_value ("rightpane", "True");
+        config_set_boolean ("Interface", "rightpane", TRUE);
         gtk_toggle_tool_button_set_active (gui->previewoff, FALSE);
     } else {
         gtk_widget_hide (GTK_WIDGET (gui->rightpane));
-        config_set_value ("rightpane", "False");
+        config_set_boolean ("Interface", "rightpane", FALSE);
         gtk_toggle_tool_button_set_active (gui->previewoff, TRUE);
     }
 }
@@ -443,8 +468,8 @@ void on_menu_docstat_activate (GtkWidget *widget, void *user) {
     GMatchInfo* match_info;
     GRegex* regexs[TEXCOUNT_OUTPUT_LINES];
     gchar* res[TEXCOUNT_OUTPUT_LINES] = { 0 };
-    
-    
+
+
     /* TODO: can we deprecate this? */
     const gchar* terms[] = {
         _("Words in text"),
@@ -455,7 +480,7 @@ void on_menu_docstat_activate (GtkWidget *widget, void *user) {
         _("Number of math inlines"),
         _("Number of math displayed")
     };
-    
+
     const gchar* terms_regex[] = {
         "Words in text: ([0-9]*)",
         "Words in headers: ([0-9]*)",
@@ -512,19 +537,19 @@ void on_menu_docstat_activate (GtkWidget *widget, void *user) {
         return;
     }
 
-    gchararray items[6] = {"stats_words", "stats_head", "stats_float", 
+    gchararray items[6] = {"stats_words", "stats_head", "stats_float",
                            "stats_nrhead", "stats_nrfloat", "stats_nrmath"};
     int j = 0;
     GtkLabel *tmp;
-        
+
     for (j = 0; j < 6; j++) {
         gchar *value = items[j];
         tmp = GTK_LABEL(gtk_builder_get_object (gui->builder, value));
         gtk_label_set_text (tmp, res[j]);
     }
-    
 
-    gtk_label_set_text (GTK_LABEL (gtk_builder_get_object (gui->builder, 
+
+    gtk_label_set_text (GTK_LABEL (gtk_builder_get_object (gui->builder,
                     "stats_filename")), tabmanagergui_get_labeltext (g_active_tab->page));
     gtk_widget_show (gui->docstatswindow);
     return;
@@ -544,36 +569,34 @@ void on_menu_spelling_toggled (GtkWidget *widget, void *user) {
     GList *editors;
     GuEditor* ec;
     int ectotal, i;
-    
-    gboolean activate = gtk_check_menu_item_get_active 
-                        (GTK_CHECK_MENU_ITEM (widget));
-    
+
+    gboolean active_status = gtk_check_menu_item_get_active
+                             (GTK_CHECK_MENU_ITEM (widget));
+
     editors = gummi_get_all_editors ();
     ectotal = g_list_length (editors);
-    
+
     for (i=0; i<ectotal; i++) {
         ec = g_list_nth_data (editors, i);
-        if (activate) {
+        if (active_status) {
             editor_activate_spellchecking (ec, TRUE);
         }
-        else { 
+        else {
             editor_activate_spellchecking (ec, FALSE);
         }
     }
-    if (activate) config_set_value ("spelling", "True");
-    else { config_set_value ("spelling", "False"); }
-            
+    config_set_boolean ("Editor", "spelling", active_status);
 #endif
 }
 
 G_MODULE_EXPORT
 void on_menu_snippets_toggled (GtkWidget *widget, void *user) {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) {
-        slog(L_INFO, "snippets activated\n");
-        config_set_value ("snippets", "True");
+        slog(L_INFO, "Snippets activated\n");
+        config_set_boolean ("Interface", "snippets", TRUE);
     } else {
-        slog(L_INFO, "snippets deactivated\n");
-        config_set_value ("snippets", "False");
+        slog(L_INFO, "Snippets deactivated\n");
+        config_set_boolean ("Interface", "snippets", FALSE);
     }
 }
 
@@ -584,24 +607,24 @@ void on_menu_snippets_toggled (GtkWidget *widget, void *user) {
 G_MODULE_EXPORT
 void on_menu_project_activate (GtkWidget *widget, void *user) {
     // TODO: perhaps use buffer to run pre compile check */
-    
+
     if (g_active_editor == NULL) {
-		gtk_widget_set_tooltip_text (GTK_WIDGET 
+		gtk_widget_set_tooltip_text (GTK_WIDGET
 					 (gui->menugui->menu_projcreate),
 					_("This function requires an active document"));
 		return;
 	}
-    
+
     if (!gummi_project_active()) {
         gtk_widget_set_sensitive (GTK_WIDGET
                                  (gui->menugui->menu_projopen), TRUE);
         // TODO we should probably have functions for calls like this:
         if (g_active_editor->filename != NULL) {
             gtk_widget_set_sensitive (GTK_WIDGET
-                                 (gui->menugui->menu_projcreate), TRUE);                    
+                                 (gui->menugui->menu_projcreate), TRUE);
         }
         else {
-			gtk_widget_set_tooltip_text (GTK_WIDGET 
+			gtk_widget_set_tooltip_text (GTK_WIDGET
 					 (gui->menugui->menu_projcreate),
 					_("This function requires the current\n"
 					  "active document to be saved. "));
@@ -628,7 +651,7 @@ void on_menu_projcreate_activate (GtkWidget *widget, void *user) {
 
     gchar* filename = get_save_filename (TYPE_PROJECT);
     if (!filename) return;
-    
+
     if (project_create_new (filename)) {
         projectgui_enable (gummi->project, gui->projectgui);
         projectgui_list_projfiles (gummi->project->projfile);
@@ -637,7 +660,7 @@ void on_menu_projcreate_activate (GtkWidget *widget, void *user) {
 
 G_MODULE_EXPORT
 void on_menu_projopen_activate (GtkWidget *widget, void *user) {
-    
+
     gchar* filename = get_open_filename (TYPE_PROJECT);
     if (!filename) return;
 
@@ -655,14 +678,14 @@ void on_menu_projopen_activate (GtkWidget *widget, void *user) {
 
 G_MODULE_EXPORT
 void on_menu_projclose_activate (GtkWidget *widget, void *user) {
-    
+
     if (!gummi->project->projfile) return;
-    
+
     if (project_close ()) {
         projectgui_disable (gummi->project, gui->projectgui);
     }
-    
-    
+
+
 }
 
 /*******************************************************************************
@@ -673,25 +696,14 @@ G_MODULE_EXPORT
 void on_menu_guide_activate (GtkWidget *widget, void *user) {
     GError *error = NULL;
 
-    gtk_show_uri (gdk_screen_get_default(), 
-                  C_GUMMIGUIDE, GDK_CURRENT_TIME, &error);
-    
+    gtk_show_uri_on_window (GTK_WINDOW (gui->mainwindow),
+                            C_PACKAGE_GUIDE, GDK_CURRENT_TIME, &error);
+
     if (error) {
         slog (L_ERROR, "Can't open user guide: %s\n", error->message);
     }
 }
 
-G_MODULE_EXPORT
-void on_menu_update_activate (GtkWidget *widget, void *user) {
-    #ifdef WIN32
-        slog (L_G_INFO, "To be implemented for win32..\n");
-    #else
-        gboolean ret = updatecheck (gui->mainwindow);
-        if (!ret)
-            slog (L_G_ERROR, "Update check failed!\n");
-    #endif
-}
-
 G_MODULE_EXPORT
 void on_menu_about_activate (GtkWidget *widget, void *user) {
     GError* err = NULL;
@@ -699,65 +711,23 @@ void on_menu_about_activate (GtkWidget *widget, void *user) {
     GdkPixbuf* icon = gdk_pixbuf_new_from_file_at_size (icon_file, 80, 80, &err);
     g_free (icon_file);
 
-    const gchar* authors[] = { "Alexander van der Mey\n"
-        "<alexvandermey@gmail.com>",
-        "Wei-Ning Huang\n"
-        "<aitjcize@gmail.com>",
-        "Dion Timmermann",
-        "<dion.timmermann@tu-harburg.de>", 
-        "Robert Schroll",
-        "<rschroll@gmail.com>\n",
-        "Former contributors:",
-        "Thomas van der Burgt",
-        "Cameron Grout", NULL };
-
-    const gchar* translators =
-        "**  Visit our website for instructions on  **\n"
-        "**  contributing or updating a translation **\n"
-        "\n"
-        "Arabic: Hamad Mohammad\n"
-        "Brazilian-Portugese: Fernando Cruz & Alexandre Guimarães\n"
-        "Catalan: Marc Vinyals\n"
-        "Chinese (Simplified): Mathlab pass\n"
-        "Chinese (Traditional): Wei-Ning Huang\n"
-        "Czech: Přemysl Janouch\n"
-        "Danish: Jack Olsen\n"
-        "Dutch: Alexander van der Mey\n"
-        "French: Yvan Duron & Olivier Brousse\n"
-        "German: Thomas Niederprüm\n"
-        "Greek: Dimitris Leventeas\n"
-        "Hungarian: Balázs Meskó\n"
-        "Italian: Salvatore Vassallo\n"
-        "Polish: Hubert Kowalski\n"
-        "Portugese: Alexandre Guimarães\n"
-        "Romanian: Alexandru-Eugen Ichim\n"
-        "Russian: Kruvalig\n"
-        "Swedish: Kess Vargavind\n"
-        "Spanish: Carlos Salas Contreras\n";
-        
-    const gchar* documenters[] = {"Guy Edwards", NULL};
+    const gchar* developers[]  = {C_CREDITS_DEVELOPERS, NULL};
+    const gchar* documenters[] = {C_CREDITS_DOCUMENTERS, NULL};
+    const gchar* translators   = C_CREDITS_TRANSLATORS;
 
     GtkAboutDialog* dialog = GTK_ABOUT_DIALOG (gtk_about_dialog_new ());
     gtk_window_set_transient_for (GTK_WINDOW (dialog), gui->mainwindow);
     gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-    gtk_about_dialog_set_authors (dialog, authors);
-    gtk_about_dialog_set_program_name (dialog, PACKAGE_NAME);
-    gtk_about_dialog_set_version (dialog, PACKAGE_VERSION);
-    gtk_about_dialog_set_website (dialog, PACKAGE_URL);
-    gtk_about_dialog_set_copyright (dialog, PACKAGE_COPYRIGHT);
-    gtk_about_dialog_set_license (dialog, PACKAGE_LICENSE);
+    gtk_about_dialog_set_authors (dialog, developers);
+    gtk_about_dialog_set_program_name (dialog, C_PACKAGE_NAME);
+    gtk_about_dialog_set_version (dialog, C_PACKAGE_VERSION);
+    gtk_about_dialog_set_website (dialog, C_PACKAGE_URL);
+    gtk_about_dialog_set_copyright (dialog, C_PACKAGE_COPYRIGHT);
+    gtk_about_dialog_set_license (dialog, C_PACKAGE_LICENSE);
     gtk_about_dialog_set_logo (dialog, icon);
-    gtk_about_dialog_set_comments (dialog, PACKAGE_COMMENTS);
+    gtk_about_dialog_set_comments (dialog, C_PACKAGE_COMMENTS);
     gtk_about_dialog_set_translator_credits (dialog, translators);
     gtk_about_dialog_set_documenters (dialog, documenters);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (GTK_WIDGET (dialog));
 }
-
-
-
-
-
-
-
-
