@@ -2,7 +2,7 @@
  * @file   gui-prefs.c
  * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -67,7 +67,7 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
     GtkBuilder* builder = gtk_builder_new ();
     gchar* ui = g_build_filename (GUMMI_DATA, "ui", "prefs.glade", NULL);
     gtk_builder_add_from_file (builder, ui, NULL);
-    gtk_builder_set_translation_domain (builder, PACKAGE);
+    gtk_builder_set_translation_domain (builder, C_PACKAGE);
     g_free (ui);
 
     p->prefwindow =
@@ -79,9 +79,9 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
     p->wordwrap_button =
         GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "wordwrapping"));
     p->line_numbers =
-        GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "line_numbers")); 
+        GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "line_numbers"));
     p->highlighting =
-        GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "highlighting")); 
+        GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "highlighting"));
     p->tabwidth =
         GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "tabwidth"));
     p->spaces_instof_tabs =
@@ -89,22 +89,20 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
     p->autoindentation =
         GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "autoindentation"));
     p->autosaving =
-        GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "autosaving")); 
+        GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "autosaving"));
     p->compile_status =
-        GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "compile_status")); 
+        GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "compile_status"));
     p->autosave_timer =
         GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "autosave_timer"));
     p->combo_languages =
-        GTK_COMBO_BOX (gtk_builder_get_object (builder, "combo_languages"));
-    p->list_languages =
-        GTK_LIST_STORE (gtk_builder_get_object (builder, "list_languages"));
+        GTK_COMBO_BOX_TEXT (gtk_builder_get_object (builder, "combo_languages"));
     p->styleschemes_treeview =
         GTK_TREE_VIEW(gtk_builder_get_object(builder, "styleschemes_treeview"));
     p->list_styleschemes =
         GTK_LIST_STORE (gtk_builder_get_object (builder, "list_styleschemes"));
     p->default_text =
         GTK_TEXT_VIEW (gtk_builder_get_object (builder, "default_text"));
-    p->default_buffer = 
+    p->default_buffer =
         gtk_text_view_get_buffer (p->default_text);
     p->editor_font =
         GTK_FONT_BUTTON (gtk_builder_get_object (builder, "editor_font"));
@@ -114,7 +112,7 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
         GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "compile_timer"));
     p->autoexport =
         GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "auto_export"));
-        
+
     p->typ_pdflatex =
         GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "typ_pdflatex"));
     p->typ_xelatex =
@@ -130,48 +128,46 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
         GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "method_texdvipdf"));
     p->method_texdvipspdf =
         GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "method_texdvipspdf"));
-        
-    p->opt_shellescape = 
+
+    p->opt_shellescape =
         GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "opt_shellescape"));
-    p->opt_synctex = 
+    p->opt_synctex =
         GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "opt_synctex"));
-        
+
+    p->combo_zoom_modes =
+        GTK_COMBO_BOX (gtk_builder_get_object (builder, "combo_zoom_modes"));
+    p->list_zoom_modes =
+        GTK_LIST_STORE (gtk_builder_get_object (builder, "list_zoom_modes"));
     p->combo_animated_scroll =
         GTK_COMBO_BOX (gtk_builder_get_object (builder, "combo_animated_scroll"));
     p->spin_cache_size =
         GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "spin_cache_size"));
-        
-    p->view_box = GTK_VBOX (gtk_builder_get_object (builder, "view_box"));
-    p->editor_box = GTK_HBOX (gtk_builder_get_object (builder, "editor_box"));
-    p->compile_box = GTK_HBOX (gtk_builder_get_object (builder, "compile_box"));
 
     gtk_window_set_transient_for (GTK_WINDOW (p->prefwindow), mainwindow);
 
 #ifdef USE_GTKSPELL
     /* list available languages */
 
-    
+
     if (g_file_test (
         g_find_program_in_path("enchant-lsmod"), G_FILE_TEST_EXISTS)) {
-            
+
         Tuple2 pret = utils_popen_r ("enchant-lsmod -list-dicts", NULL);
         if (pret.second != NULL) {
             gchar** output = g_strsplit((gchar*)pret.second, "\n", BUFSIZ);
             gchar** elems = NULL;
             int i;
-    
+
             for(i = 0; output[i] != NULL; i++) {
-                GtkTreeIter iter;
                 elems = g_strsplit (output[i], " ", BUFSIZ);
                 if (elems[0] != NULL) {
-                    gtk_list_store_append (p->list_languages, &iter);
-                    gtk_list_store_set (p->list_languages, &iter, 0, elems[0], -1);
+                    gtk_combo_box_text_append_text (p->combo_languages, elems[0]);
                 }
             }
         g_strfreev(output);
         g_strfreev(elems);
         }
-        gtk_combo_box_set_active (p->combo_languages, 0);
+        gtk_combo_box_set_active (GTK_COMBO_BOX(p->combo_languages), 0);
         g_free ((gchar*)pret.second);
     }
 #else
@@ -184,6 +180,7 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
     GList* schemes_iter = schemes;
     gchar* desc = NULL;
     GtkTreeIter iter;
+
     while (schemes_iter) {
         desc = g_markup_printf_escaped ("<b>%s</b> - %s",
                 gtk_source_style_scheme_get_name (schemes_iter->data),
@@ -195,6 +192,7 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
         schemes_iter = g_list_next (schemes_iter);
         g_free (desc);
     }
+
     g_list_free (schemes);
 
     gtk_builder_connect_signals (builder, NULL);
@@ -205,7 +203,7 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
 void prefsgui_main (GuPrefsGui* prefs, int page) {
 
     gtk_notebook_set_current_page(prefs->notebook, page);
-    
+
     set_all_tab_settings (prefs);
     gtk_widget_show_all (GTK_WIDGET (prefs->prefwindow));
 }
@@ -221,55 +219,48 @@ static void set_all_tab_settings (GuPrefsGui* prefs) {
 }
 
 static void set_tab_view_settings (GuPrefsGui* prefs) {
-    gboolean value = FALSE;
+    gboolean textwrap_enabled = config_get_boolean ("Editor", "textwrapping");
 
-    value = TO_BOOL (config_get_value ("textwrapping"));
-    if (value) {
+    if (textwrap_enabled) {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(prefs->textwrap_button),
-                value);
+                                      textwrap_enabled);
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(prefs->wordwrap_button),
-                TO_BOOL (config_get_value ("wordwrapping")));
+                                      config_get_boolean ("Editor", "wordwrapping"));
     } else
         gtk_widget_set_sensitive (GTK_WIDGET (prefs->wordwrap_button), FALSE);
 
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->line_numbers),
-            TO_BOOL (config_get_value ("line_numbers")));
+                                  config_get_boolean ("Editor", "line_numbers"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->highlighting),
-            TO_BOOL (config_get_value ("highlighting")));    
-    
+                                  config_get_boolean ("Editor", "highlighting"));
+
 }
 
 static void set_tab_editor_settings (GuPrefsGui* prefs) {
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->autoindentation),
-            TO_BOOL (config_get_value ("autoindentation")));
+                                  config_get_boolean ("Editor", "autoindentation"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->spaces_instof_tabs),
-            TO_BOOL (config_get_value ("spaces_instof_tabs")));
+                                  config_get_boolean ("Editor", "spaces_instof_tabs"));
     gtk_spin_button_set_value (prefs->tabwidth,
-                               atoi (config_get_value ("tabwidth")));
+                               config_get_integer ("Editor", "tabwidth"));
     gtk_spin_button_set_value (prefs->autosave_timer,
-                               atoi (config_get_value ("autosave_timer")));
+                               config_get_integer ("File", "autosave_timer"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->autosaving),
-            TO_BOOL (config_get_value ("autosaving")));
-    if (!config_get_value ("autosaving"))
+                                  config_get_boolean ("File", "autosaving"));
+    if (!config_get_boolean ("File", "autosaving"))
         gtk_widget_set_sensitive (GTK_WIDGET (prefs->autosave_timer), FALSE);
 }
 
 static void set_tab_fontcolor_settings (GuPrefsGui* prefs) {
-    const gchar* font = config_get_value ("font");
-
-    PangoFontDescription* font_desc = pango_font_description_from_string (font);
-    gtk_widget_modify_font (GTK_WIDGET (prefs->default_text), font_desc);
-    pango_font_description_free (font_desc);
-    
-    gtk_font_button_set_font_name (prefs->editor_font, 
-                                        config_get_value ("font"));
+    gtk_font_chooser_set_font (GTK_FONT_CHOOSER (prefs->editor_font),
+                               config_get_string ("Editor", "font"));
     prefsgui_apply_style_scheme(prefs);
 }
 
 static void set_tab_defaulttext_settings (GuPrefsGui* prefs) {
-    
+
     gchar* text = NULL;
-    
+
     if (!g_file_get_contents (C_WELCOMETEXT, &text, NULL, NULL)) {
         gtk_widget_set_sensitive (GTK_WIDGET(prefs->default_text), FALSE);
         return;
@@ -283,31 +274,31 @@ static void set_tab_compilation_settings (GuPrefsGui* prefs) {
     /* Setting available typesetters and the active one */
     /* TODO: iterate the available typesetter list and gtk_builder the objects
      * maybe.. or not.. */
-     
-    
+
+
     if (pdflatex_detected()) {
-        if (pdflatex_active()) 
+        if (pdflatex_active())
             gtk_toggle_button_set_active (prefs->typ_pdflatex, TRUE);
         gtk_widget_set_sensitive (GTK_WIDGET(prefs->typ_pdflatex), TRUE);
         gtk_widget_set_tooltip_text (GTK_WIDGET(prefs->typ_pdflatex), "");
     }
-    
+
     if (xelatex_detected()) {
-        if (xelatex_active()) 
+        if (xelatex_active())
             gtk_toggle_button_set_active (prefs->typ_xelatex, TRUE);
         gtk_widget_set_sensitive (GTK_WIDGET(prefs->typ_xelatex), TRUE);
         gtk_widget_set_tooltip_text (GTK_WIDGET(prefs->typ_xelatex), "");
     }
-    
+
     if (rubber_detected()) {
-        if (rubber_active()) 
+        if (rubber_active())
             gtk_toggle_button_set_active (prefs->typ_rubber, TRUE);
         gtk_widget_set_sensitive (GTK_WIDGET(prefs->typ_rubber), TRUE);
         gtk_widget_set_tooltip_text (GTK_WIDGET(prefs->typ_rubber), "");
     }
-    
+
     if (latexmk_detected()) {
-        if (latexmk_active()) 
+        if (latexmk_active())
             gtk_toggle_button_set_active (prefs->typ_latexmk, TRUE);
         gtk_widget_set_sensitive (GTK_WIDGET(prefs->typ_latexmk), TRUE);
         gtk_widget_set_tooltip_text (GTK_WIDGET(prefs->typ_latexmk), "");
@@ -315,22 +306,22 @@ static void set_tab_compilation_settings (GuPrefsGui* prefs) {
 
     if (latex_method_active ("texpdf")) {
         gtk_toggle_button_set_active (prefs->method_texpdf, TRUE);
-    }    
+    }
     else if (latex_method_active ("texdvipdf")) {
         gtk_toggle_button_set_active (prefs->method_texdvipdf, TRUE);
     }
     else if (latex_method_active ("texdvipspdf")) {
         gtk_toggle_button_set_active (prefs->method_texdvipspdf, TRUE);
     }
-    
+
     if (!latex_use_shellescaping())
         gtk_toggle_button_set_active (prefs->opt_shellescape, FALSE);
     else {
         gtk_toggle_button_set_active (prefs->opt_shellescape, TRUE);
     }
-    
+
     if (latex_can_synctex()) {
-        if (config_get_value ("synctex")) {
+        if (config_get_boolean ("Compile", "synctex")) {
             gtk_toggle_button_set_active (prefs->opt_synctex, TRUE);
         }
         else {
@@ -342,27 +333,50 @@ static void set_tab_compilation_settings (GuPrefsGui* prefs) {
 static void set_tab_preview_settings (GuPrefsGui* prefs) {
 
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->compile_status),
-            TO_BOOL (config_get_value ("compile_status")));
+                                  config_get_boolean ("Compile", "status"));
 
-    if (!config_get_value ("compile_status"))
+    if (!config_get_boolean ("Compile", "status"))
         gtk_widget_set_sensitive (GTK_WIDGET (prefs->compile_timer), FALSE);
-        
+
     gtk_spin_button_set_value (prefs->compile_timer,
-                               atoi (config_get_value ("compile_timer")));
-    /* compile scheme */
-    if (STR_EQU (config_get_value ("compile_scheme"), "real_time"))
+                               config_get_integer ("Compile", "timer"));
+    // compile scheme:
+    if (config_value_as_str_equals ("Compile", "scheme", "real_time"))
         gtk_combo_box_set_active (prefs->compile_scheme, 1);
-                               
-    if (STR_EQU (config_get_value ("animated_scroll"), "always")) {
+
+    // default zoom mode:
+    GtkTreeModel* model = 0;
+    GtkTreeIter iter;
+    gboolean valid = FALSE;
+    gint count = 0;
+
+    const gchar *conf_str = config_get_string("Preview", "zoom_mode");
+
+    model = gtk_combo_box_get_model (GTK_COMBO_BOX (prefs->combo_zoom_modes));
+    valid = gtk_tree_model_get_iter_first (model, &iter);
+
+    while (valid) {
+        const gchar* list_str;
+        gtk_tree_model_get (model, &iter, 0, &list_str, -1);
+        if (STR_EQU (list_str, conf_str)) {
+            gtk_combo_box_set_active (GTK_COMBO_BOX (prefs->combo_zoom_modes), count);
+            break;
+        }
+        ++count;
+        valid = gtk_tree_model_iter_next (model, &iter);
+    }
+
+    // animated scroll:
+    if (config_value_as_str_equals ("Preview", "animated_scroll", "always")) {
         gtk_combo_box_set_active (prefs->combo_animated_scroll, 0);
-    } else if (STR_EQU (config_get_value ("animated_scroll"), "never")) {
+    } else if (config_value_as_str_equals ("Preview", "animated_scroll", "never")) {
         gtk_combo_box_set_active (prefs->combo_animated_scroll, 2);
     } else {
         gtk_combo_box_set_active (prefs->combo_animated_scroll, 1);
     }
-    
+
     gtk_spin_button_set_value (prefs->spin_cache_size,
-                               atoi (config_get_value ("cache_size")));
+                               config_get_integer ("Preview", "cache_size"));
 }
 
 static void set_tab_miscellaneous_settings (GuPrefsGui* prefs) {
@@ -372,28 +386,28 @@ static void set_tab_miscellaneous_settings (GuPrefsGui* prefs) {
     gint count = 0;
     gboolean valid = FALSE;
 
-    combo_lang = gtk_combo_box_get_model (prefs->combo_languages);
+    combo_lang = gtk_combo_box_get_model (GTK_COMBO_BOX (prefs->combo_languages));
+
+    lang = config_get_string ("Editor", "spelling_lang");
 
-    lang = config_get_value ("spell_language");
     valid = gtk_tree_model_get_iter_first (combo_lang, &iter);
     while (valid) {
         const gchar* str_value;
         gtk_tree_model_get (combo_lang, &iter, 0, &str_value, -1);
         if (STR_EQU (lang, str_value)) {
-            gtk_combo_box_set_active (prefs->combo_languages, count);
+            gtk_combo_box_set_active (GTK_COMBO_BOX (prefs->combo_languages), count);
             break;
         }
         ++count;
         valid = gtk_tree_model_iter_next (combo_lang, &iter);
-    }    
-    
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->autoexport),
-            TO_BOOL (config_get_value ("autoexport")));
+    }
 
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->autoexport),
+                                  config_get_boolean ("File", "autoexport"));
 }
 
 void prefsgui_apply_style_scheme(GuPrefsGui* prefs) {
-    const gchar* scheme = config_get_value ("style_scheme");
+    const gchar* scheme = config_get_string ("Editor", "style_scheme");
     GList* schemes = editor_list_style_scheme_sorted ();
     GList* schemes_iter = schemes;
     GList* tab = gummi->tabmanager->tabs;
@@ -434,7 +448,8 @@ void toggle_linenumbers (GtkWidget* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
     GList* tab = gummi->tabmanager->tabs;
 
-    config_set_value ("line_numbers", newval? "True": "False");
+    config_set_boolean ("Editor", "line_numbers", newval);
+
     while (tab) {
         gtk_source_view_set_show_line_numbers (GTK_SOURCE_VIEW
                 (GU_TAB_CONTEXT (tab->data)->editor->view), newval);
@@ -447,8 +462,8 @@ void toggle_highlighting (GtkWidget* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
     GList* tab = gummi->tabmanager->tabs;
 
-    config_set_value ("highlighting", newval? "True": "False");
-    
+    config_set_boolean ("Editor", "highlighting", newval);
+
     while (tab) {
         gtk_source_view_set_highlight_current_line (GTK_SOURCE_VIEW
                 (GU_TAB_CONTEXT (tab->data)->editor->view), newval);
@@ -461,7 +476,8 @@ void toggle_textwrapping (GtkWidget* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
     GList* tab = gummi->tabmanager->tabs;
 
-    config_set_value ("textwrapping", newval? "True": "False");
+    config_set_boolean ("Editor", "textwrapping", newval);
+
     if (newval) {
         while (tab) {
             gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW
@@ -492,7 +508,8 @@ void toggle_wordwrapping (GtkWidget* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
     GList* tab = gummi->tabmanager->tabs;
 
-    config_set_value ("wordwrapping", newval? "True": "False");
+    config_set_boolean ("Editor", "wordwrapping", newval);
+
     while (tab) {
         if (newval)
             gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW
@@ -507,7 +524,8 @@ void toggle_wordwrapping (GtkWidget* widget, void* user) {
 G_MODULE_EXPORT
 void toggle_compilestatus (GtkWidget* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-    config_set_value ("compile_status", newval? "True": "False");
+    config_set_boolean ("Compile", "status", newval);
+
     gtk_widget_set_sensitive (GTK_WIDGET(gui->prefsgui->compile_timer), newval);
     gtk_toggle_tool_button_set_active (gui->previewoff, !newval);
 }
@@ -515,9 +533,9 @@ void toggle_compilestatus (GtkWidget* widget, void* user) {
 G_MODULE_EXPORT
 void toggle_spaces_instof_tabs (GtkWidget* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-    GList* tab = gummi->tabmanager->tabs;
+    config_set_boolean ("Editor", "spaces_instof_tabs", newval);
 
-    config_set_value ("spaces_instof_tabs", newval? "True": "False");
+    GList* tab = gummi->tabmanager->tabs;
     while (tab) {
         gtk_source_view_set_insert_spaces_instead_of_tabs
             (GU_TAB_CONTEXT (tab->data)->editor->view, newval);
@@ -528,9 +546,9 @@ void toggle_spaces_instof_tabs (GtkWidget* widget, void* user) {
 G_MODULE_EXPORT
 void toggle_autoindentation (GtkWidget* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-    GList* tab = gummi->tabmanager->tabs;
+    config_set_boolean ("Editor", "autoindentation", newval);
 
-    config_set_value ("autoindentation", newval? "True": "False");
+    GList* tab = gummi->tabmanager->tabs;
     while (tab) {
         gtk_source_view_set_auto_indent
             (GU_TAB_CONTEXT (tab->data)->editor->view, newval);
@@ -541,13 +559,13 @@ void toggle_autoindentation (GtkWidget* widget, void* user) {
 G_MODULE_EXPORT
 void toggle_autosaving (GtkWidget* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+    config_set_boolean ("File", "autosaving", newval);
 
-    config_set_value ("autosaving", newval? "True": "False");
     if (newval) {
         gtk_widget_set_sensitive (
                 GTK_WIDGET (gui->prefsgui->autosave_timer), TRUE);
-        gint time = atoi (config_get_value ("autosave_timer"));
-        gtk_spin_button_set_value (gui->prefsgui->autosave_timer, time);
+        gtk_spin_button_set_value (gui->prefsgui->autosave_timer,
+                                   config_get_integer ("File", "autosave_timer"));
         iofunctions_reset_autosave (g_active_editor->filename);
     } else {
         gtk_widget_set_sensitive (
@@ -559,7 +577,7 @@ void toggle_autosaving (GtkWidget* widget, void* user) {
 G_MODULE_EXPORT
 void toggle_autoexport (GtkWidget* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-    config_set_value ("autoexport", newval? "True": "False");
+    config_set_boolean ("File", "autoexport", newval);
 }
 
 G_MODULE_EXPORT
@@ -572,8 +590,8 @@ void on_prefs_close_clicked (GtkWidget* widget, void* user) {
         gtk_text_buffer_get_end_iter (gui->prefsgui->default_buffer, &end);
         text = gtk_text_buffer_get_text (gui->prefsgui->default_buffer, &start,
                                          &end, FALSE);
-                                         
-        utils_set_file_contents (C_WELCOMETEXT, text, -1);  
+
+        utils_set_file_contents (C_WELCOMETEXT, text, -1);
     }
     g_free (text);
 
@@ -582,19 +600,18 @@ void on_prefs_close_clicked (GtkWidget* widget, void* user) {
 
 G_MODULE_EXPORT
 void on_prefs_reset_clicked (GtkWidget* widget, void* user) {
-    config_set_default ();
+    config_load_defaults ();
     utils_copy_file (C_DEFAULTTEXT, C_WELCOMETEXT, NULL);
-    
+
     set_all_tab_settings (gui->prefsgui);
 }
 
 G_MODULE_EXPORT
 void on_tabwidth_value_changed (GtkWidget* widget, void* user) {
     gint newval = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
-    gchar buf[16];
+    config_set_integer ("Editor", "tabwidth", newval);
+    
     GList* tab = gummi->tabmanager->tabs;
-
-    config_set_value ("tabwidth", g_ascii_dtostr (buf, 16, (double)newval));
     while (tab) {
         gtk_source_view_set_tab_width (GU_TAB_CONTEXT (tab->data)->editor->view,
                                       newval);
@@ -610,54 +627,46 @@ void on_configure_snippets_clicked (GtkWidget* widget, void* user) {
 G_MODULE_EXPORT
 void on_autosave_value_changed (GtkWidget* widget, void* user) {
     gint newval = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
-    gchar buf[16];
+    config_set_integer("File", "autosave_timer", newval);
 
-    config_set_value("autosave_timer", g_ascii_dtostr(buf, 16, (double)newval));
     iofunctions_reset_autosave (g_active_editor->filename);
 }
 
 G_MODULE_EXPORT
 void on_compile_value_changed (GtkWidget* widget, void* user) {
     gint newval = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
-    gchar buf[16];
+    config_set_integer("Compile", "timer", newval);
 
-    config_set_value("compile_timer", g_ascii_dtostr (buf, 16, (double)newval));
     previewgui_reset (gui->previewgui);
 }
 
 G_MODULE_EXPORT
-void on_cache_size_value_changed(GtkWidget* widget, void* user) {
+void on_cache_size_value_changed (GtkWidget* widget, void* user) {
     gint newval = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
-    gchar buf[16];
+    config_set_integer ("Preview", "cache_size", newval);
 
-    config_set_value("cache_size", g_ascii_dtostr (buf, 16, (double)newval));
-    
-     
     g_idle_add((GSourceFunc) run_garbage_collector, gui->previewgui);
 }
 
 G_MODULE_EXPORT
 void on_editor_font_set (GtkWidget* widget, void* user) {
-    const gchar* font = gtk_font_button_get_font_name(GTK_FONT_BUTTON (widget));
-    PangoFontDescription* font_desc = pango_font_description_from_string (font);
+    gchar* font = gtk_font_chooser_get_font ( GTK_FONT_CHOOSER (widget));
     GList* tab = gummi->tabmanager->tabs;
 
     slog (L_INFO, "setting font to %s\n", font);
-    config_set_value ("font", font);
+    config_set_string ("Editor", "font", font);
 
     while (tab) {
-        gtk_widget_modify_font (GTK_WIDGET
-                (GU_TAB_CONTEXT (tab->data)->editor->view), font_desc);
+        editor_set_font (GU_TAB_CONTEXT (tab->data)->editor, font);
         tab = g_list_next (tab);
     }
-    pango_font_description_free (font_desc);
 }
 
 
 G_MODULE_EXPORT
 void on_typ_pdflatex_toggled (GtkToggleButton* widget, void* user) {
     if (gtk_toggle_button_get_active (widget)) {
-        config_set_value ("typesetter", "pdflatex");
+        config_set_string ("Compile", "typesetter", "pdflatex");
         typesetter_setup ();
     }
 }
@@ -665,16 +674,15 @@ void on_typ_pdflatex_toggled (GtkToggleButton* widget, void* user) {
 G_MODULE_EXPORT
 void on_typ_xelatex_toggled (GtkToggleButton* widget, void* user) {
     if (gtk_toggle_button_get_active (widget)) {
-        config_set_value ("typesetter", "xelatex");
+        config_set_string ("Compile", "typesetter", "xelatex");
         typesetter_setup ();
     }
-
 }
 
 G_MODULE_EXPORT
 void on_typ_rubber_toggled (GtkToggleButton* widget, void* user) {
     if (gtk_toggle_button_get_active (widget)) {
-        config_set_value ("typesetter", "rubber");
+        config_set_string ("Compile", "typesetter", "rubber");
         typesetter_setup ();
     }
 }
@@ -682,7 +690,7 @@ void on_typ_rubber_toggled (GtkToggleButton* widget, void* user) {
 G_MODULE_EXPORT
 void on_typ_latexmk_toggled (GtkToggleButton* widget, void* user) {
     if (gtk_toggle_button_get_active (widget)) {
-        config_set_value ("typesetter", "latexmk");
+        config_set_string ("Compile", "typesetter", "latexmk");
         typesetter_setup ();
     }
 }
@@ -690,16 +698,16 @@ void on_typ_latexmk_toggled (GtkToggleButton* widget, void* user) {
 G_MODULE_EXPORT
 void on_method_texpdf_toggled (GtkToggleButton* widget, void* user) {
     if (gtk_toggle_button_get_active (widget)) {
-        config_set_value ("compile_steps", "texpdf");
+        config_set_string ("Compile", "steps", "texpdf");
         slog (L_INFO, "Changed compile method to \"tex->pdf\"\n");
     }
-    
+
 }
 
 G_MODULE_EXPORT
 void on_method_texdvipdf_toggled (GtkToggleButton* widget, void* user) {
     if (gtk_toggle_button_get_active (widget)) {
-        config_set_value ("compile_steps", "texdvipdf");
+        config_set_string ("Compile", "steps", "texdvipdf");
         slog (L_INFO, "Changed compile method to \"tex->dvi->pdf\"\n");
     }
 }
@@ -707,7 +715,7 @@ void on_method_texdvipdf_toggled (GtkToggleButton* widget, void* user) {
 G_MODULE_EXPORT
 void on_method_texdvipspdf_toggled (GtkToggleButton* widget, void* user) {
     if (gtk_toggle_button_get_active (widget)) {
-        config_set_value ("compile_steps", "texdvipspdf");
+        config_set_string ("Compile", "steps", "texdvipspdf");
         slog (L_INFO, "Changed compile method to \"tex->dvi->ps->pdf\"\n");
     }
 }
@@ -715,24 +723,24 @@ void on_method_texdvipspdf_toggled (GtkToggleButton* widget, void* user) {
 G_MODULE_EXPORT
 void toggle_shellescape (GtkToggleButton* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-    config_set_value ("shellescape", newval? "True": "False");
+    config_set_boolean ("Compile", "shellescape", newval);
 }
 
 G_MODULE_EXPORT
 void on_synctex_toggled (GtkToggleButton* widget, void* user) {
     gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-    config_set_value ("synctex", newval? "True": "False");
+    config_set_boolean ("Compile", "synctex", newval);
     gtk_widget_set_sensitive (GTK_WIDGET (gui->menu_autosync), newval);
 }
 
 G_MODULE_EXPORT
-void on_combo_language_changed (GtkWidget* widget, void* user) {
+void on_combo_language_changed (GtkComboBoxText* widget, void* user) {
 #ifdef USE_GTKSPELL
-    gchar* selected = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
+    gchar* selected = gtk_combo_box_text_get_active_text (widget);
     GList* tab = gummi->tabmanager->tabs;
-    config_set_value ("spell_language", selected);
+    config_set_string ("Editor", "spelling_lang", selected);
 
-    if (config_get_value ("spelling")) {
+    if (config_get_boolean ("Editor", "spelling")) {
         while (tab) {
             editor_activate_spellchecking (GU_TAB_CONTEXT (tab->data)->editor,
                                            FALSE);
@@ -741,23 +749,33 @@ void on_combo_language_changed (GtkWidget* widget, void* user) {
             tab = g_list_next (tab);
         }
     }
+    g_free(selected);
 #endif
 }
 
 G_MODULE_EXPORT
 void on_combo_compilescheme_changed (GtkWidget* widget, void* user) {
     gint selected = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
-    const gchar scheme[][16] = { "on_idle", "real_time" };
+    gchar scheme[][16] = { "on_idle", "real_time" };
     slog (L_INFO, "compile scheme set to %s\n", scheme[selected]);
-    config_set_value ("compile_scheme", scheme[selected]);
+    config_set_string ("Compile", "scheme", scheme[selected]);
     previewgui_reset (gui->previewgui);
 }
 
+G_MODULE_EXPORT
+void on_combo_zoom_modes_changed (GtkWidget* widget, void* user) {
+    gint selected = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
+    // lazily duplicating this again for now (TODO fix in 0.8.1)
+    gchar scheme[][16] = {"Best Fit", "Fit Page Width", "50%", "70%", "85%",
+                          "100%", "125%", "150%", "200%", "300%", "400%"};
+    config_set_string ("Preview", "zoom_mode", scheme[selected]);
+}
+
 G_MODULE_EXPORT
 void on_combo_animated_scroll_changed (GtkWidget* widget, void* user) {
     gint selected = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
-    const gchar scheme[][16] = { "always", "autosync", "never" };
-    config_set_value ("animated_scroll", scheme[selected]);
+    gchar scheme[][16] = { "always", "autosync", "never" };
+    config_set_string ("Preview", "animated_scroll", scheme[selected]);
 }
 
 G_MODULE_EXPORT
@@ -776,5 +794,5 @@ void on_styleschemes_treeview_cursor_changed (GtkTreeView* treeview, void* user)
         editor_set_style_scheme_by_id (GU_TAB_CONTEXT (tab->data)->editor, id);
         tab = g_list_next (tab);
     }
-    config_set_value ("style_scheme", id);
+    config_set_string ("Editor", "style_scheme", id);
 }
