@@ -1,10 +1,10 @@
 /**
  * @file   gui-preview.h
- * @brief   
+ * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
- * 
+ *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
  * files (the "Software"), to deal in the Software without
@@ -31,7 +31,7 @@
 #define __GUMMI_GUI_PREVIEW_H__
 
 #include <gtk/gtk.h>
-#include <poppler.h> 
+#include <poppler.h>
 
 #define PAGE_MARGIN 14
 #define DOCUMENT_MARGIN (PAGE_MARGIN/2)
@@ -47,14 +47,14 @@
 #define BYTES_PER_PIXEL 4
 
 /**
- *  These "Layered" Rectangles are just like normal GdkRectangles, except the 
+ *  These "Layered" Rectangles are just like normal GdkRectangles, except the
  *  have a layer assigned. 2 Rectangles can only intersect or be unioned if they
  *  are on the same layer.
- * 
- *  In the future these structs should be used to describe the position of a 
- *  page. In continuous mode all pages are on the same layer (0). In Paged mode, 
- *  they are on different layers. The field of view (fov) rectangle, that 
- *  describes the portion of the preview that is currently visible is on the 
+ *
+ *  In the future these structs should be used to describe the position of a
+ *  page. In continuous mode all pages are on the same layer (0). In Paged mode,
+ *  they are on different layers. The field of view (fov) rectangle, that
+ *  describes the portion of the preview that is currently visible is on the
  *  layer/page that should currently be displayed (0 in continuous mode).
  */
 typedef struct _LayeredRectangle LayeredRectangle;
@@ -66,25 +66,25 @@ struct _LayeredRectangle {
     gint layer;
 };
 
-enum GuPreviewFitMode {
-    FIT_NONE = 0, 
-    FIT_WIDTH, 
-    FIT_HEIGHT, 
-    FIT_BOTH
+enum GuPreviewFitModes {
+    FIT_BOTH = 0,       // Best Fit
+    FIT_WIDTH,          // Fit Page Width
+    FIT_NUMERIC         // 50,85,100 .. 400 %
 };
 
+
 #define GU_PREVIEW_PAGE(x) ((GuPreviewPage*)(x))
 typedef struct _GuPreviewPage GuPreviewPage;
 
 struct _GuPreviewPage {
     cairo_surface_t* rendering;
-    
+
     double height;
     double width;
-    
+
     LayeredRectangle inner; // Position of the page itself
     LayeredRectangle outer; // Position of the page + border & shadow
-    
+
 };
 
 #define GU_PREVIEW_GUI(x) ((GuPreviewGui*)x)
@@ -92,22 +92,25 @@ typedef struct _GuPreviewGui GuPreviewGui;
 
 struct _GuPreviewGui {
     PopplerDocument* doc;
-    GtkViewport* previewgui_viewport;
-    GtkWidget* previewgui_toolbar;
-    GtkWidget* statuslight;
+
+    GtkWidget* scrollw;
+    GtkViewport* viewport;
     GtkWidget* drawarea;
+    GtkWidget* toolbar;
+
+
     GtkWidget* page_next;
     GtkWidget* page_prev;
     GtkWidget* page_label;
     GtkWidget* page_input;
-    GtkWidget* scrollw;
+
     GtkWidget* errorpanel;
     GtkComboBox* combo_sizes;
 
     gulong page_input_changed_handler;
     gulong combo_sizes_changed_handler;
     gulong on_resize_handler;
-    gulong on_expose_handler;
+    gulong on_draw_handler;
     gulong hvalue_changed_handler;
     gulong vvalue_changed_handler;
     gulong hchanged_handler;
@@ -117,15 +120,14 @@ struct _GuPreviewGui {
     GtkRadioMenuItem *page_layout_one_column;
 
     gchar *uri;
-    gint update_timer;
+    guint update_timer;
     gboolean preview_on_idle;
+    gboolean errormode;
 
     GtkAdjustment* hadj;
     GtkAdjustment* vadj;
     gdouble prev_x;
     gdouble prev_y;
-    gdouble restore_x;
-    gdouble restore_y;
 
     gint n_pages;
     gint current_page;
@@ -139,9 +141,8 @@ struct _GuPreviewGui {
     gdouble scale;
     PopplerPageLayout pageLayout;
     GuPreviewPage *pages;
-    enum GuPreviewFitMode fit_mode;
     gint cache_size;
-    
+
     gint document_width_scaling;
     gint document_height_scaling;
     gint document_width_non_scaling;
@@ -160,7 +161,6 @@ struct _GuPreviewGui {
 };
 
 GuPreviewGui* previewgui_init (GtkBuilder * builder);
-void previewgui_update_statuslight (const gchar* type);
 void previewgui_set_pdffile (GuPreviewGui* prev, const gchar *uri);
 void previewgui_refresh (GuPreviewGui* prev, GtkTextIter *sync_to, gchar* tex_file);
 void previewgui_set_pagedata (GuPreviewGui* prev);
@@ -179,7 +179,7 @@ void on_page_input_changed (GtkEntry* entry, void* user);
 void on_next_page_clicked (GtkWidget* widget, void* user);
 void on_prev_page_clicked (GtkWidget* widget, void* user);
 void on_combo_sizes_changed (GtkWidget* widget, void* user);
-gboolean on_expose (GtkWidget* w, GdkEventExpose* e, void* user);
+gboolean on_draw (GtkWidget* w, cairo_t* cr, void* user);
 gboolean on_scroll (GtkWidget* w, GdkEventScroll* e, void* user);
 gboolean on_motion (GtkWidget* w, GdkEventMotion* e, void* user);
 gboolean on_resize (GtkWidget* w, GdkRectangle* r, void* user);
@@ -189,6 +189,11 @@ void on_adj_changed(GtkAdjustment *adjustment, gpointer user);
 void previewgui_page_layout_radio_changed(GtkMenuItem *radioitem,gpointer data);
 void previewgui_set_page_layout(GuPreviewGui* pc, PopplerPageLayout pageLayout);
 
+void previewgui_start_errormode (GuPreviewGui *pc, const gchar *msg);
+void previewgui_stop_errormode (GuPreviewGui *pc);
+gboolean on_document_compiled (gpointer data);
+gboolean on_document_error (gpointer data);
+
 gboolean run_garbage_collector(GuPreviewGui* pc);
 
 
