@@ -2,7 +2,7 @@
  * @file   gummi.c
  * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -37,6 +37,7 @@
 
 #include "biblio.h"
 #include "configfile.h"
+#include "constants.h"
 #include "environment.h"
 #include "external.h"
 #include "gui/gui-main.h"
@@ -55,95 +56,81 @@ static int debug = 0;
 static int showversion = 0;
 
 static GOptionEntry entries[] = {
-    { (const gchar*)"debug", (gchar)'d', 0, G_OPTION_ARG_NONE, 
+    { (const gchar*)"debug", (gchar)'d', 0, G_OPTION_ARG_NONE,
         &debug, (gchar*)"show debug info", NULL},
-    { (const gchar*)"version", (gchar)'v', 0, G_OPTION_ARG_NONE, 
+    { (const gchar*)"version", (gchar)'v', 0, G_OPTION_ARG_NONE,
         &showversion, (gchar*)"show version and exit", NULL},
     { NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
 };
 
-void on_window_destroy (GtkObject *object, gpointer user_data) {
-    gtk_main_quit ();
-}
-
 int main (int argc, char *argv[]) {
     /* set up i18n */
-    bindtextdomain (PACKAGE, GUMMI_LOCALES);
+    bindtextdomain (C_PACKAGE, GUMMI_LOCALES);
     setlocale (LC_ALL, "");
-    textdomain (PACKAGE);
+    textdomain (C_PACKAGE);
 
     GError* error = NULL;
     GOptionContext* context = g_option_context_new ("files");
-    g_option_context_add_main_entries (context, entries, PACKAGE);
+    g_option_context_add_main_entries (context, entries, C_PACKAGE);
     g_option_context_parse (context, &argc, &argv, &error);
     if (error) g_error("%s\n", error->message);
-    
+
     if (showversion) {
-        printf("Gummi %s\n", PACKAGE_VERSION);
+        printf("Gummi %s\n", C_PACKAGE_VERSION);
         return 0;
     }
 
     /* initialize GTK */
-    g_thread_init (NULL);
-    gdk_threads_init ();
     gtk_init (&argc, &argv);
     GError* ui_error = NULL;
     GtkBuilder* builder = gtk_builder_new ();
     gchar* ui = g_build_filename (GUMMI_DATA, "ui", "gummi.glade", NULL);
-    
+
     // exit program when gummi.glade can not be located:
     if (!g_file_test (ui, G_FILE_TEST_EXISTS)) {
         printf("Could not locate Glade interface file at:\n%s\n", ui);
         return 0;
     }
-    
+
     gtk_builder_add_from_file (builder, ui, &ui_error);
     if (ui_error) {
         g_error ("%s\n", ui_error->message);
     }
-    gtk_builder_set_translation_domain (builder, PACKAGE);
+    gtk_builder_set_translation_domain (builder, C_PACKAGE);
     g_free (ui);
 
     /* Initialize logging */
     slog_init (debug);
-    slog (L_INFO, PACKAGE_NAME" version: "PACKAGE_VERSION"\n");
+    slog (L_INFO, C_PACKAGE_NAME" version: "C_PACKAGE_VERSION"\n");
 
-    /* Initialize configuration */
-    gchar* configname = g_build_filename (g_get_user_config_dir (), "gummi",
-                                  "gummi.cfg", NULL);
-    config_init (configname);
-    config_load ();
-    g_free (configname);
+    // Initialize configuration
+    config_init ();
 
     /* Initialize signals */
     gummi_signals_register ();
 
     /* Initialize Classes */
-    gchar* snippetsname = g_build_filename (g_get_user_config_dir (), "gummi",
-            "snippets.cfg", NULL);
-
     // why do we not load this from environment, like gui-main does? -A
     GuMotion* motion = motion_init ();
     GuIOFunc* io = iofunctions_init();
-    GuLatex* latex = latex_init (); 
+    GuLatex* latex = latex_init ();
     GuBiblio* biblio = biblio_init (builder);
     GuTemplate* templ = template_init (builder);
     GuTabmanager* tabm = tabmanager_init ();
     GuProject* proj = project_init ();
+    GuSnippets* snippets = snippets_init ();
 
-    GuSnippets* snippets = snippets_init (snippetsname);
     gummi = gummi_init (motion, io, latex, biblio, templ, snippets, tabm, proj);
     slog (L_DEBUG, "Gummi created!\n");
-    g_free (snippetsname);
 
     /* Initialize GUI */
     gui = gui_init (builder);
-    
+
     slog_set_gui_parent (gui->mainwindow);
     slog (L_DEBUG, "GummiGui created!\n");
 
     /* Start compile thread */
-    if (external_exists (config_get_value("typesetter"))) {
+    if (external_exists (config_get_string ("Compile", "typesetter"))) {
         typesetter_setup ();
         motion_start_compile_thread (motion);
     }
@@ -154,22 +141,28 @@ int main (int argc, char *argv[]) {
 
     /* Install acceleration group to mainwindow */
     gtk_window_add_accel_group (gui->mainwindow, snippets->accel_group);
-
-    if (argc != 2)
+    
+    // tab/file loading:
+    if (argc < 2) {
         tabmanager_create_tab (A_DEFAULT, NULL, NULL);
-    else {
-        if (!g_file_test(argv[1], G_FILE_TEST_EXISTS)) {
-            slog(L_ERROR, "Failed to open file '%s': No such file or "
-                    "directory\n", argv[1]);
-            exit(1);
-        }
-        tabmanager_create_tab (A_LOAD, argv[1], NULL);
     }
-        
-    if (config_get_value ("autosaving")) iofunctions_start_autosave ();
+    else {
+        int i;
+        for (i = 1; i < argc; i++) {
+            if (!g_file_test(argv[i], G_FILE_TEST_EXISTS)) {
+                slog(L_ERROR, "Failed to open file '%s': "
+                              "No such file or directory\n", argv[i]);
+                exit(1);
+            }
+            tabmanager_create_tab (A_LOAD, argv[i], NULL);
+        }
+    }
+
+    if (config_get_boolean ("File", "autosaving")) {
+        iofunctions_start_autosave ();
+    }
 
     gui_main (builder);
     config_save ();
-    config_clean_up ();
     return 0;
 }
