@@ -1,10 +1,10 @@
 /**
  * @file   motion.c
- * @brief  
+ * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
- * 
+ *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
  * files (the "Software"), to deal in the Software without
@@ -55,15 +55,6 @@
 #include "snippets.h"
 #include "utils.h"
 
-/* set up uri using appropriate formatting for OS
-   http://en.wikipedia.org/wiki/File_URI_scheme#Linux */
-#ifdef WIN32
-    const gchar *urifrmt = "file:///";
-#else
-    const gchar *urifrmt = "file://";
-#endif
-
-
 extern GummiGui* gui;
 extern Gummi* gummi;
 
@@ -74,9 +65,9 @@ GuMotion* motion_init (void) {
     GuMotion* m = g_new0 (GuMotion, 1);
 
     m->key_press_timer = 0;
-    m->signal_mutex = g_mutex_new ();
-    m->compile_mutex = g_mutex_new ();
-    m->compile_cv = g_cond_new ();
+    g_mutex_init(&m->signal_mutex);
+    g_mutex_init(&m->compile_mutex);
+    g_cond_init(&m->compile_cv);
     m->keep_running = TRUE;
     m->keep_running = FALSE;
     m->typesetter_pid = &typesetter_pid;
@@ -85,14 +76,8 @@ GuMotion* motion_init (void) {
 }
 
 void motion_start_compile_thread (GuMotion* m) {
-    GError* err = NULL;
-
     m->keep_running = TRUE;
-    m->compile_thread = g_thread_create (motion_compile_thread, m, TRUE, &err);
-    if (!m->compile_thread) {
-        slog (L_G_FATAL, "Can not create new thread: %s\n", err->message);
-        g_error_free(err);
-    }
+    m->compile_thread = g_thread_new ("motion", motion_compile_thread, m);
 }
 
 void motion_stop_compile_thread (GuMotion* m) {
@@ -131,13 +116,13 @@ void motion_kill_typesetter (GuMotion* m) {
 
         /* Make sure typesetter command is terminated */
         if (kill(*m->typesetter_pid, 15)) {
-            slog(L_ERROR, "Could not kill process: %s\n", 
+            slog(L_ERROR, "Could not kill process: %s\n",
                                     g_strerror(errno));
         }
 #else
         if (!TerminateProcess(*m->typesetter_pid, 0)) {
             gchar *msg = g_win32_error_message(GetLastError());
-            slog (L_ERROR, "Could not kill process: %s\n", 
+            slog (L_ERROR, "Could not kill process: %s\n",
                                     msg ? msg : "(null)");
             g_free(msg);
         }
@@ -157,12 +142,12 @@ gboolean motion_do_compile (gpointer user) {
     L_F_DEBUG;
     GuMotion* mc = GU_MOTION (user);
 
-    if (!g_mutex_trylock (mc->signal_mutex)) goto ret;
-    g_cond_signal (mc->compile_cv);
-    g_mutex_unlock (mc->signal_mutex);
+    if (!g_mutex_trylock (&mc->signal_mutex)) goto ret;
+    g_cond_signal (&mc->compile_cv);
+    g_mutex_unlock (&mc->signal_mutex);
 
 ret:
-    return (STR_EQU (config_get_value ("compile_scheme"), "real_time"));
+    return (config_value_as_str_equals ("Compile", "scheme", "real_time"));
 }
 
 gpointer motion_compile_thread (gpointer data) {
@@ -170,84 +155,53 @@ gpointer motion_compile_thread (gpointer data) {
     GuMotion* mc = GU_MOTION (data);
     GuEditor* editor = NULL;
     GuLatex* latex = NULL;
-    GuPreviewGui* pc = NULL;
-    GtkWidget* focus = NULL;
     gboolean precompile_ok = FALSE;
-    gboolean compile_status = FALSE;
     gchar *editortext;
 
     latex = gummi_get_latex ();
-    pc = gui->previewgui;
-    
+
     while (TRUE) {
-        if (!g_mutex_trylock (mc->compile_mutex)) continue;
+        if (!g_mutex_trylock (&mc->compile_mutex)) continue;
         slog (L_DEBUG, "Compile thread sleeping...\n");
-        g_cond_wait (mc->compile_cv, mc->compile_mutex);
+        g_cond_wait (&mc->compile_cv, &mc->compile_mutex);
         slog (L_DEBUG, "Compile thread awoke.\n");
 
         if (!(editor = gummi_get_active_editor ())) {
-            g_mutex_unlock (mc->compile_mutex);
+            g_mutex_unlock (&mc->compile_mutex);
             continue;
         }
         if (!mc->keep_running) {
-            g_mutex_unlock (mc->compile_mutex);
+            g_mutex_unlock (&mc->compile_mutex);
             g_thread_exit (NULL);
         }
 
         if (mc->pause) {
-            g_mutex_unlock (mc->compile_mutex);
+            g_mutex_unlock (&mc->compile_mutex);
             continue;
         }
 
         gdk_threads_enter ();
-        focus = gtk_window_get_focus (gui->mainwindow);
         editortext = latex_update_workfile (latex, editor);
-        
         precompile_ok = latex_precompile_check (editortext);
         g_free (editortext);
-
-        gtk_widget_grab_focus (focus);
+        gdk_threads_leave ();
 
         if (!precompile_ok) {
-            motion_start_errormode (mc, "document_error");
-            gdk_threads_leave();
-            g_mutex_unlock (mc->compile_mutex);
+            gdk_threads_add_idle (on_document_error, "document_error");
+            g_mutex_unlock (&mc->compile_mutex);
             continue;
         }
-        gdk_threads_leave();
-        
-        compile_status = latex_update_pdffile (latex, editor);
+
+        latex_update_pdffile (latex, editor);
+
         *mc->typesetter_pid = 0;
-        g_mutex_unlock (mc->compile_mutex);
+        g_mutex_unlock (&mc->compile_mutex);
 
         if (!mc->keep_running)
             g_thread_exit (NULL);
 
-        gdk_threads_enter ();
-        previewgui_update_statuslight(compile_status? "gtk-yes": "gtk-no");
-
-        /* Make sure the editor still exists after compile */
-        if (editor == gummi_get_active_editor()) {
-            editor_apply_errortags (editor, latex->errorlines);
-            gui_buildlog_set_text (latex->compilelog);
-
-            if (latex->errorlines[0]) {
-                motion_start_errormode  (mc, "compile_error");
-            } else {
-                if (!pc->uri) {
-                    
-                    char* uri = g_strconcat (urifrmt, editor->pdffile, NULL);
-                    previewgui_set_pdffile (pc, uri);
-                    g_free(uri);
-                } else {
-                    previewgui_refresh (gui->previewgui,
-                            editor->sync_to_last_edit ?
-                            &(editor->last_edit) : NULL, editor->workfile);
-                }
-                if (mc->errormode) motion_stop_errormode (mc);
-            }
-        }
-        gdk_threads_leave ();
+        gdk_threads_add_idle (on_document_compiled, editor);
+        continue;
     }
 }
 
@@ -258,30 +212,8 @@ void motion_force_compile (GuMotion *mc) {
     motion_do_compile (mc);
 }
 
-void motion_start_errormode (GuMotion *mc, const gchar *msg) {
-    
-    if (mc->errormode) {
-        infoscreengui_set_message (gui->infoscreengui, msg);
-    return;
-    }
-
-    previewgui_save_position (gui->previewgui);
-    
-    infoscreengui_enable (gui->infoscreengui, msg);
-    mc->errormode = TRUE;
-}
-
-void motion_stop_errormode (GuMotion *mc) {
-    
-    if (!mc->errormode) return;
-
-    previewgui_restore_position (gui->previewgui);
-    
-    infoscreengui_disable (gui->infoscreengui);
-    mc->errormode = FALSE;
-}
-
 gboolean motion_idle_cb (gpointer user) {
+    GU_MOTION(user)->key_press_timer = 0;
     if (gui->previewgui->preview_on_idle)
         motion_do_compile (GU_MOTION (user));
     return FALSE;
@@ -289,8 +221,9 @@ gboolean motion_idle_cb (gpointer user) {
 
 void motion_start_timer (GuMotion* mc) {
     motion_stop_timer (mc);
-    mc->key_press_timer = g_timeout_add_seconds (atoi (
-                config_get_value ("compile_timer")), motion_idle_cb, mc);
+    mc->key_press_timer = g_timeout_add_seconds (
+                                config_get_integer ("Compile", "timer"),
+                                motion_idle_cb, mc);
 }
 
 void motion_stop_timer (GuMotion* mc) {
@@ -304,7 +237,7 @@ gboolean on_key_press_cb (GtkWidget* widget, GdkEventKey* event, void* user) {
     if (!event->is_modifier) {
         motion_stop_timer (GU_MOTION (user));
     }
-    if (config_get_value("snippets") && 
+    if (config_get_boolean ("Interface", "snippets") &&
         snippets_key_press_cb (gummi_get_snippets (),
                                gummi_get_active_editor (), event))
         return TRUE;
@@ -315,7 +248,7 @@ gboolean on_key_release_cb (GtkWidget* widget, GdkEventKey* event, void* user) {
     if (!event->is_modifier) {
         motion_start_timer (GU_MOTION (user));
     }
-    if (config_get_value("snippets") && 
+    if (config_get_boolean ("Interface", "snippets") &&
         snippets_key_release_cb (gummi_get_snippets (),
                                  gummi_get_active_editor (), event))
         return TRUE;
