@@ -1,10 +1,10 @@
 /**
  * @file   motion.h
- * @brief   
+ * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
- * 
+ *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
  * files (the "Software"), to deal in the Software without
@@ -37,13 +37,13 @@
 typedef struct _GuMotion GuMotion;
 
 struct _GuMotion {
-    gint key_press_timer;
-    GMutex* signal_mutex;
-    GMutex* compile_mutex;
+    guint key_press_timer;
+    GMutex signal_mutex;
+    GMutex compile_mutex;
     GThread* compile_thread;
-    GCond* compile_cv;
+    GCond compile_cv;
     pid_t* typesetter_pid;
-    
+
     gboolean keep_running;
     gboolean pause;
     gboolean errormode;
@@ -62,9 +62,6 @@ void motion_start_timer (GuMotion* mc);
 void motion_stop_timer (GuMotion* mc);
 void motion_kill_typesetter (GuMotion* m);
 
-void motion_start_errormode (GuMotion *mc, const gchar *msg);
-void motion_stop_errormode (GuMotion *mc);
-
 gboolean on_key_press_cb (GtkWidget* widget, GdkEventKey* event, void* user);
 gboolean on_key_release_cb (GtkWidget* widget, GdkEventKey* event, void* user);
 
