@@ -1,10 +1,10 @@
 /**
  * @file    utils.c
- * @brief   
+ * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
- * 
+ *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
  * files (the "Software"), to deal in the Software without
@@ -91,7 +91,6 @@ void slog_set_gui_parent (GtkWindow* p) {
 
 void slog (gint level, const gchar *fmt, ...) {
     gchar message[BUFSIZ];
-    gchar* out;
     va_list vap;
 
     if (L_IS_TYPE (level, L_DEBUG) && !slog_debug) return;
@@ -118,21 +117,11 @@ void slog (gint level, const gchar *fmt, ...) {
     if (L_IS_GUI (level)) {
         GtkWidget* dialog;
 
-        if (L_IS_TYPE (level, L_G_FATAL))
-            out = g_strdup_printf (_("%s has encountered a serious error and "
-                        "will require a restart. Your working data will be "
-                        "restored when you reload your document. Please "
-                        "report bugs at: http://dev.midnightcoding.org"),
-                        PACKAGE_NAME);
-        else
-            out = g_strdup (message);
-
-        dialog = gtk_message_dialog_new (parent, 
+        dialog = gtk_message_dialog_new (parent,
                 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                 L_IS_TYPE (level,L_G_INFO)? GTK_MESSAGE_INFO: GTK_MESSAGE_ERROR,
                 GTK_BUTTONS_OK,
                 "%s", message);
-        g_free (out);
 
         if (L_IS_TYPE (level, L_G_ERROR))
             gtk_window_set_title (GTK_WINDOW (dialog), "Error!");
@@ -146,27 +135,47 @@ void slog (gint level, const gchar *fmt, ...) {
     }
 
     if (!L_IS_TYPE (level, L_INFO) &&
-        !L_IS_TYPE (level, L_DEBUG) && 
-        !L_IS_TYPE (level, L_ERROR) && 
+        !L_IS_TYPE (level, L_DEBUG) &&
+        !L_IS_TYPE (level, L_ERROR) &&
         !L_IS_TYPE (level, L_G_INFO) &&
         !L_IS_TYPE (level, L_G_ERROR))
         exit (1);
 }
 
+gint utils_save_reload_dialog (const gchar* message) {
+    GtkWidget* dialog;
+    gint ret = 0;
+
+    g_return_val_if_fail (message != NULL, 0);
+
+    dialog = gtk_message_dialog_new (parent,
+                 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                 GTK_MESSAGE_QUESTION,
+                 GTK_BUTTONS_NONE,
+                 "%s", message);
+    gtk_dialog_add_buttons(GTK_DIALOG (dialog), "Reload", GTK_RESPONSE_YES, "Save", GTK_RESPONSE_NO, NULL);
+
+    gtk_window_set_title (GTK_WINDOW (dialog), _("Confirmation"));
+    ret = gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (dialog);
+
+    return ret;
+}
+
 gint utils_yes_no_dialog (const gchar* message) {
     GtkWidget* dialog;
     gint ret = 0;
 
     g_return_val_if_fail (message != NULL, 0);
 
-    dialog = gtk_message_dialog_new (parent, 
+    dialog = gtk_message_dialog_new (parent,
                  GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                  GTK_MESSAGE_QUESTION,
                  GTK_BUTTONS_YES_NO,
                  "%s", message);
 
     gtk_window_set_title (GTK_WINDOW (dialog), _("Confirmation"));
-    ret = gtk_dialog_run (GTK_DIALOG (dialog));      
+    ret = gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 
     return ret;
@@ -181,6 +190,15 @@ gboolean utils_path_exists (const gchar* path) {
     return result;
 }
 
+gboolean utils_uri_path_exists (const gchar* uri) {
+    gboolean result = FALSE;
+    
+    gchar *filepath = g_filename_from_uri(uri, NULL, NULL);
+    result = utils_path_exists(filepath);
+    g_free(filepath);
+    return(result);
+}
+
 gboolean utils_set_file_contents (const gchar *filename, const gchar *text,
                                   gssize length) {
     /* g_file_set_contents may not work correctly on Windows. See the
@@ -251,7 +269,7 @@ Tuple2 utils_popen_r (const gchar* cmd, const gchar* chdir) {
             ret = g_strdup (buf);
         g_free (rot);
     }
-    
+
     // close the file descriptor:
     close(pout);
 
@@ -260,11 +278,11 @@ Tuple2 utils_popen_r (const gchar* cmd, const gchar* chdir) {
     #else
         waitpid(typesetter_pid, &status, 0);
     #endif
-    
+
     // See bug 446:
     if (ret) {
         if (!g_utf8_validate (ret, -1, NULL)) {
-            ret = g_convert_with_fallback (ret, -1, "UTF-8", 
+            ret = g_convert_with_fallback (ret, -1, "UTF-8",
                     "ISO-8859-1", NULL, NULL, NULL, NULL);
         }
     }
@@ -283,18 +301,18 @@ gchar* utils_path_to_relative (const gchar* root, const gchar* target) {
 
 gchar* utils_get_tmp_tmp_dir (void) {
 	/* brb, gonna go punch a wall */
-    gchar *tmp_tmp = g_build_path 
+    gchar *tmp_tmp = g_build_path
 						(C_DIRSEP, g_get_home_dir(), "gtmp", NULL);
     g_mkdir_with_parents (tmp_tmp, DIR_PERMS);
 
     return tmp_tmp;
-}  
+}
 
 
 gboolean utils_glist_is_member (GList* list, gchar* item) {
     int nrofitems = g_list_length (list);
     int i;
-    
+
     for (i=0;i<nrofitems;i++) {
         if (STR_EQU (item, g_list_nth_data (list,i))) {
             return TRUE;
